@@ -1,12 +1,4 @@
 class Target
-  private
-  def qt_libraries args = {}
-    libs  = ''
-    libs += "-L#{c(:QT_PLUGINS_DIR)}/platforms -lqwindows " if c?(:MINGW)
-    libs += c(:QT_LIBS)
-    return libs
-  end
-
   public
 
   begin
@@ -89,6 +81,11 @@ class Target
     @objects       = ( @objects      + new_deps.collect { |a| a.first }.select { |file| obj_re.match file } ).uniq
     @dependencies  = ( @dependencies + new_deps.collect { |a| a.first }                                     ).uniq
     @file_deps     = ( @file_deps    + new_file_deps                                                        ).uniq
+
+    if c?(:USE_PRECOMPILED_HEADERS)
+      new_deps.select { |dep| /\.moco$/.match dep[0] }.each { |dep| file dep[0] => [ dep[0].ext('.moc'), "src/common/common_pch.h.gch" ] }
+    end
+
     self
   end
 
@@ -143,7 +140,7 @@ class Target
       when :boost_regex      then c(:BOOST_REGEX_LIB)
       when :boost_filesystem then c(:BOOST_FILESYSTEM_LIB)
       when :boost_system     then c(:BOOST_SYSTEM_LIB)
-      when :qt               then qt_libraries
+      when :qt               then c(:QT_LIBS)
       when :wxwidgets        then c(:WXWIDGETS_LIBS)
       when :static           then c(:LINK_STATICALLY)
       when :mpegparser       then [ '-Lsrc/mpegparser', '-lmpegparser'  ]
@@ -154,8 +151,8 @@ class Target
       when :mtxextract       then [ '-Lsrc/extract',    '-lmtxextract'  ]
       when :mtxpropedit      then [ '-Lsrc/propedit',   '-lmtxpropedit' ]
       when :mtxunittest      then [ '-Ltests/unit',     '-lmtxunittest' ]
-      when :ebml             then c(:EBML_LIBS)
-      when :matroska         then c(:MATROSKA_LIBS)
+      when :ebml             then '-lebml'
+      when :matroska         then '-lmatroska'
       when String            then entry
       else                        "-l#{entry}"
       end
