@@ -2,7 +2,7 @@
    mkvmerge -- utility for splicing together matroska files
    from component media subtypes
 
-   Distributed under the GPL
+   Distributed under the GPL v2
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
@@ -85,7 +85,6 @@ namespace ac3 {
 
     int find_consecutive_frames(unsigned char const *buffer, size_t buffer_size, size_t num_required_headers);
 
-  protected:
     void parse(bool end_of_stream);
   };
 };
