@@ -135,7 +135,7 @@ std::string
 fourcc_c::description()
   const {
   static auto s_id_fmt   = boost::format("0x%|1$08x| »%2%%3%%4%%5%«");
-  static auto s_name_fmt = boost::format(" (%1%)");
+  static auto s_name_fmt = boost::format(": %1%");
 
   unsigned char buffer[4];
   put_uint32_be(buffer, m_value);
