@@ -18,8 +18,8 @@
 
 #include "common/common_pch.h"
 
+#include <cmath>
 #include <unordered_map>
-#include <boost/math/special_functions/round.hpp>
 
 #include "common/bit_cursor.h"
 #include "common/byte_buffer.h"
@@ -1061,7 +1061,7 @@ parse_vps(memory_cptr &buffer,
   //buffer = mcptr_newvps;
   //buffer->set_size(w.get_bit_position() / 8);
 
-  vps.checksum = mtx::checksum::calculate_as_uint(mtx::checksum::adler32, *buffer);
+  vps.checksum = mtx::checksum::calculate_as_uint(mtx::checksum::algorithm_e::adler32, *buffer);
 
   return true;
 }
@@ -1117,11 +1117,12 @@ parse_sps(memory_cptr &buffer,
   sps.width = w.copy_unsigned_golomb(r); // pic_width_in_luma_samples
   sps.height = w.copy_unsigned_golomb(r); // pic_height_in_luma_samples
 
-  if (w.copy_bits(1, r) == 1) {
-    w.copy_unsigned_golomb(r); // conf_win_left_offset
-    w.copy_unsigned_golomb(r); // conf_win_right_offset
-    w.copy_unsigned_golomb(r); // conf_win_top_offset
-    w.copy_unsigned_golomb(r); // conf_win_bottom_offset
+  sps.conformance_window_flag = w.copy_bits(1, r);
+  if (sps.conformance_window_flag) {
+    sps.conf_win_left_offset   = w.copy_unsigned_golomb(r); // conf_win_left_offset
+    sps.conf_win_right_offset  = w.copy_unsigned_golomb(r); // conf_win_right_offset
+    sps.conf_win_top_offset    = w.copy_unsigned_golomb(r); // conf_win_top_offset
+    sps.conf_win_bottom_offset = w.copy_unsigned_golomb(r); // conf_win_bottom_offset
   }
 
   sps.bit_depth_luma_minus8 = w.copy_unsigned_golomb(r); // bit_depth_luma_minus8
@@ -1190,7 +1191,17 @@ parse_sps(memory_cptr &buffer,
   buffer = mcptr_newsps;
   buffer->set_size(w.get_bit_position() / 8);
 
-  sps.checksum = mtx::checksum::calculate_as_uint(mtx::checksum::adler32, *buffer);
+  sps.checksum = mtx::checksum::calculate_as_uint(mtx::checksum::algorithm_e::adler32, *buffer);
+
+  // See ITU-T H.265 section 7.4.3.2 for the width/height calculation
+  // formula.
+  if (sps.conformance_window_flag) {
+    auto sub_width_c  = ((1 == sps.chroma_format_idc) || (2 == sps.chroma_format_idc)) && (0 == sps.separate_colour_plane_flag) ? 2 : 1;
+    auto sub_height_c =  (1 == sps.chroma_format_idc)                                  && (0 == sps.separate_colour_plane_flag) ? 2 : 1;
+
+    sps.width        -= std::min<unsigned int>((sub_width_c  * sps.conf_win_right_offset)  + (sub_width_c  * sps.conf_win_left_offset), sps.width);
+    sps.height       -= std::min<unsigned int>((sub_height_c * sps.conf_win_bottom_offset) + (sub_height_c * sps.conf_win_top_offset),  sps.height);
+  }
 
   return true;
 }
@@ -1215,7 +1226,7 @@ parse_pps(memory_cptr &buffer,
     pps.output_flag_present_flag = r.get_bits(1);  // output_flag_present_flag
     pps.num_extra_slice_header_bits = r.get_bits(3);  // num_extra_slice_header_bits
 
-    pps.checksum          = mtx::checksum::calculate_as_uint(mtx::checksum::adler32, *buffer);
+    pps.checksum          = mtx::checksum::calculate_as_uint(mtx::checksum::algorithm_e::adler32, *buffer);
 
     return true;
   } catch (...) {
@@ -2318,8 +2329,8 @@ es_parser_c::get_display_dimensions(int width,
   if (0 >= height)
     height = get_height();
 
-  return std::make_pair<int64_t, int64_t>(1 <= m_par ? boost::math::llround(width * boost::rational_cast<double>(m_par)) : width,
-                                          1 <= m_par ? height                                                            : boost::math::llround(height / boost::rational_cast<double>(m_par)));
+  return std::make_pair<int64_t, int64_t>(1 <= m_par ? std::llround(width * boost::rational_cast<double>(m_par)) : width,
+                                          1 <= m_par ? height                                                    : std::llround(height / boost::rational_cast<double>(m_par)));
 }
 
 size_t
@@ -2345,7 +2356,7 @@ es_parser_c::dump_info()
            % format_timecode(frame.m_start)
            % format_timecode(frame.m_end)
            % format_timecode(frame.m_ref1)
-           % mtx::checksum::calculate_as_uint(mtx::checksum::adler32, *frame.m_data));
+           % mtx::checksum::calculate_as_uint(mtx::checksum::algorithm_e::adler32, *frame.m_data));
   }
 }
 
