@@ -2,7 +2,7 @@
    mkvmerge -- utility for splicing together matroska files
    from component media subtypes
 
-   Distributed under the GPL
+   Distributed under the GPL v2
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
@@ -25,7 +25,7 @@ using namespace libebml;
 using namespace libmatroska;
 
 class kax_analyzer_data_c;
-typedef std::shared_ptr<kax_analyzer_data_c> kax_analyzer_data_cptr;
+using kax_analyzer_data_cptr = std::shared_ptr<kax_analyzer_data_c>;
 
 class kax_analyzer_data_c {
 public:
@@ -132,6 +132,9 @@ public:
     return -1;
   }
 
+  virtual uint64_t get_segment_pos() const;
+  virtual uint64_t get_segment_data_start_pos() const;
+
   virtual bool process(parse_mode_e parse_mode = parse_mode_full, const open_mode mode = MODE_WRITE, bool throw_on_error = false);
 
   virtual void show_progress_start(int64_t /* size */) {
@@ -154,6 +157,9 @@ public:
 
   virtual void close_file();
   virtual void reopen_file(const open_mode = MODE_WRITE);
+  virtual mm_file_io_c &get_file() {
+    return *m_file;
+  }
 
   static placement_strategy_e get_placement_strategy_for(EbmlElement *e);
   static placement_strategy_e get_placement_strategy_for(ebml_element_cptr e) {
@@ -185,7 +191,7 @@ protected:
 protected:
   virtual bool process_internal(parse_mode_e parse_mode, const open_mode mode);
 };
-typedef std::shared_ptr<kax_analyzer_c> kax_analyzer_cptr;
+using kax_analyzer_cptr = std::shared_ptr<kax_analyzer_c>;
 
 class console_kax_analyzer_c: public kax_analyzer_c {
 private:
@@ -204,6 +210,6 @@ public:
 
   virtual void debug_abort_process();
 };
-typedef std::shared_ptr<console_kax_analyzer_c> console_kax_analyzer_cptr;
+using console_kax_analyzer_cptr = std::shared_ptr<console_kax_analyzer_c>;
 
 #endif  // MTX_COMMON_KAX_ANALYZER_H
