@@ -2,7 +2,7 @@
    mkvmerge -- utility for splicing together matroska files
    from component media subtypes
 
-   Distributed under the GPL
+   Distributed under the GPL v2
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
@@ -16,14 +16,27 @@
 
 #include "common/common_pch.h"
 
-#define irnd(a) ((int64_t)((double)(a) + 0.5))
-#define iabs(a) ((a) < 0 ? (a) * -1 : (a))
+#if defined(COMP_MSC)
+# include <intrin.h>
+#endif
 
-uint32_t round_to_nearest_pow2(uint32_t value);
+namespace mtx { namespace math {
 
-int int_log2(uint32_t value);
+inline std::size_t
+count_1_bits(uint64_t value) {
+#if defined(COMP_MSC)
+  return __popcnt(value);
+#else
+  return __builtin_popcountll(value);
+#endif
+}
+
+uint64_t round_to_nearest_pow2(uint64_t value);
+int int_log2(uint64_t value);
 double int_to_double(int64_t value);
 
-typedef boost::rational<int64_t> int64_rational_c;
+}}
+
+using int64_rational_c = boost::rational<int64_t>;
 
 #endif  // MTX_COMMON_MATH_H
