@@ -2,7 +2,7 @@
    mkvmerge -- utility for splicing together matroska files
    from component media subtypes
 
-   Distributed under the GPL
+   Distributed under the GPL v2
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
@@ -34,15 +34,6 @@
 #include "common/strings/parsing.h"
 #include "common/strings/utf8.h"
 
-HANDLE
-CreateFileUtf8(LPCSTR lpFileName,
-               DWORD dwDesiredAccess,
-               DWORD dwShareMode,
-               LPSECURITY_ATTRIBUTES lpSecurityAttributes,
-               DWORD dwCreationDisposition,
-               DWORD dwFlagsAndAttributes,
-               HANDLE hTemplateFile);
-
 mm_file_io_c::mm_file_io_c(const std::string &path,
                            const open_mode mode)
   : m_file_name(path)
@@ -79,7 +70,8 @@ mm_file_io_c::mm_file_io_c(const std::string &path,
   if ((MODE_WRITE == mode) || (MODE_CREATE == mode))
     prepare_path(path);
 
-  m_file = (void *)CreateFileUtf8(path.c_str(), access_mode, share_mode, nullptr, disposition, 0, nullptr);
+  auto w_path = to_wide(path);
+  m_file      = static_cast<void *>(CreateFileW(w_path.c_str(), access_mode, share_mode, nullptr, disposition, 0, nullptr));
   if (static_cast<HANDLE>(m_file) == INVALID_HANDLE_VALUE)
     throw mtx::mm_io::open_x{mtx::mm_io::make_error_code()};
 
@@ -119,6 +111,7 @@ mm_file_io_c::setFilePointer(int64 offset,
   if ((INVALID_SET_FILE_POINTER == low) && (GetLastError() != NO_ERROR))
     throw mtx::mm_io::seek_x{mtx::mm_io::make_error_code()};
 
+  m_eof              = false;
   m_current_position = (int64_t)low + ((int64_t)high << 32);
 }
 
@@ -134,9 +127,7 @@ mm_file_io_c::_read(void *buffer,
     return 0;
   }
 
-  if (size != bytes_read)
-    m_eof = true;
-
+  m_eof               = size != bytes_read;
   m_current_position += bytes_read;
 
   return bytes_read;
@@ -177,6 +168,7 @@ mm_file_io_c::_write(const void *buffer,
 
   m_current_position += bytes_written;
   m_cached_size       = -1;
+  m_eof               = false;
 
   return bytes_written;
 }
@@ -186,6 +178,11 @@ mm_file_io_c::eof() {
   return m_eof;
 }
 
+void
+mm_file_io_c::clear_eof() {
+  m_eof = false;
+}
+
 int
 mm_file_io_c::truncate(int64_t pos) {
   m_cached_size = -1;
