@@ -2,7 +2,7 @@
    mkvmerge -- utility for splicing together matroska files
    from component media subtypes
 
-   Distributed under the GPL
+   Distributed under the GPL v2
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
@@ -25,7 +25,7 @@
 
 using namespace libebml;
 
-typedef std::function<void(unsigned int level, std::string const &)> mxmsg_handler_t;
+using mxmsg_handler_t = std::function<void(unsigned int level, std::string const &)>;
 void set_mxmsg_handler(unsigned int level, mxmsg_handler_t const &handler);
 
 extern bool g_suppress_info, g_suppress_warnings;
