@@ -2,7 +2,7 @@
    mkvmerge -- utility for splicing together matroska files
    from component media subtypes
 
-   Distributed under the GPL
+   Distributed under the GPL v2
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
@@ -39,6 +39,7 @@ namespace mtx { namespace tags {
 
 void fix_mandatory_elements(EbmlElement *e);
 void remove_track_uid_targets(EbmlMaster *tag);
+void remove_elements_unsupported_by_webm(EbmlMaster &master);
 
 KaxTags *select_for_chapters(KaxTags &tags, KaxChapters &chapters);
 
