@@ -1,7 +1,7 @@
 /*
    mkvextract -- extract tracks from Matroska files into other files
 
-   Distributed under the GPL
+   Distributed under the GPL v2
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
@@ -14,7 +14,6 @@
 
 #include <cassert>
 #include <iostream>
-#include <stdlib.h>
 
 #include "common/chapters/chapters.h"
 #include "common/command_line.h"
@@ -123,6 +122,9 @@ main(int argc,
   else if (options_c::em_chapters == options.m_extraction_mode)
     extract_chapters(options.m_file_name, options.m_simple_chapter_format, options.m_parse_mode);
 
+  else if (options_c::em_cues == options.m_extraction_mode)
+    extract_cues(options.m_file_name, options.m_tracks, options.m_parse_mode);
+
   else if (options_c::em_cuesheet == options.m_extraction_mode)
     extract_cuesheet(options.m_file_name, options.m_parse_mode);
 
@@ -132,5 +134,5 @@ main(int argc,
   else
     usage(2);
 
-  mxexit(0);
+  mxexit();
 }
