@@ -1,7 +1,7 @@
 /*
    mkvextract -- extract tracks from Matroska files into other files
 
-   Distributed under the GPL
+   Distributed under the GPL v2
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
@@ -112,7 +112,7 @@ create_extractors(KaxTracks &kax_tracks,
     extractors.push_back(extractor);
 
     mxinfo(boost::format(Y("Extracting track %1% with the CodecID '%2%' to the file '%3%'. Container format: %4%\n"))
-           % track_id % codec_id % tspec->out_name % extractor->get_container_name());
+           % track_id % codec_id % extractor->get_file_name().string() % extractor->get_container_name());
   }
 
   // Signal that all headers have been taken care of.
