@@ -2,7 +2,7 @@
 
    mkvinfo -- info tracks from Matroska files into other files
 
-   Distributed under the GPL
+   Distributed under the GPL v2
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
