@@ -30,8 +30,8 @@ public:
   ac3_reader_c(const track_info_c &ti, const mm_io_cptr &in);
   virtual ~ac3_reader_c();
 
-  virtual translatable_string_c get_format_name() const {
-    return YT("AC3");
+  virtual file_type_e get_format_type() const {
+    return FILE_TYPE_AC3;
   }
 
   virtual void read_headers();
