@@ -2,7 +2,7 @@
    mkvmerge -- utility for splicing together matroska files
    from component media subtypes
 
-   Distributed under the GPL
+   Distributed under the GPL v2
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
@@ -19,7 +19,8 @@
 #include "common/ivf.h"
 #include "input/r_ivf.h"
 #include "output/p_vpx.h"
-#include "merge/output_control.h"
+#include "merge/input_x.h"
+#include "merge/file_status.h"
 
 int
 ivf_reader_c::probe_file(mm_io_c *io,
@@ -32,7 +33,7 @@ ivf_reader_c::probe_file(mm_io_c *io,
   if (io->read(&header, sizeof(ivf::file_header_t)) < sizeof(ivf::file_header_t))
     return 0;
 
-  if (memcmp(header.file_magic, "DKIF", 4) || header.get_codec().is(CT_UNKNOWN))
+  if (memcmp(header.file_magic, "DKIF", 4) || header.get_codec().is(codec_c::type_e::UNKNOWN))
     return 0;
 
   return 1;
