@@ -206,8 +206,8 @@ public:
   kax_reader_c(const track_info_c &ti, const mm_io_cptr &in);
   virtual ~kax_reader_c();
 
-  virtual translatable_string_c get_format_name() const {
-    return YT("Matroska");
+  virtual file_type_e get_format_type() const {
+    return FILE_TYPE_MATROSKA;
   }
 
   virtual void read_headers();
