@@ -440,8 +440,8 @@ public:
   qtmp4_reader_c(const track_info_c &ti, const mm_io_cptr &in);
   virtual ~qtmp4_reader_c();
 
-  virtual translatable_string_c get_format_name() const {
-    return YT("QuickTime/MP4");
+  virtual file_type_e get_format_type() const {
+    return FILE_TYPE_QTMP4;
   }
 
   virtual void read_headers();
