@@ -82,5 +82,5 @@ srt_reader_c::get_progress() {
 void
 srt_reader_c::identify() {
   id_result_container();
-  id_result_track(0, ID_RESULT_TRACK_SUBTITLES, codec_c::get_name(codec_c::type_e::S_SRT, "SRT"));
+  id_result_track(0, ID_RESULT_TRACK_SUBTITLES, codec_c::get_name(codec_c::type_e::S_SRT, "SRT"), std::vector<std::string>{"text_subtitles:1"});
 }
