@@ -2,7 +2,7 @@
    mkvmerge -- utility for splicing together matroska files
    from component media subtypes
 
-   Distributed under the GPL
+   Distributed under the GPL v2
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
@@ -18,7 +18,8 @@
 #include "common/endian.h"
 #include "common/error.h"
 #include "input/r_wavpack.h"
-#include "merge/output_control.h"
+#include "merge/input_x.h"
+#include "merge/file_status.h"
 #include "output/p_wavpack.h"
 
 int
@@ -228,5 +229,5 @@ wavpack_reader_c::read(generic_packetizer_c *,
 void
 wavpack_reader_c::identify() {
   id_result_container();
-  id_result_track(0, ID_RESULT_TRACK_AUDIO, codec_c::get_name(CT_A_WAVPACK4, "WAVPACK"));
+  id_result_track(0, ID_RESULT_TRACK_AUDIO, codec_c::get_name(codec_c::type_e::A_WAVPACK4, "WAVPACK"));
 }
