@@ -2,7 +2,7 @@
    mkvmerge -- utility for splicing together matroska files
    from component media subtypes
 
-   Distributed under the GPL
+   Distributed under the GPL v2
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
@@ -19,7 +19,9 @@
 #include "common/strings/formatting.h"
 #include "common/strings/parsing.h"
 #include "input/subtitles.h"
-#include "merge/output_control.h"
+#include "merge/file_status.h"
+#include "merge/input_x.h"
+#include "merge/generic_reader.h"
 #include "merge/packet_extensions.h"
 
 // ------------------------------------------------------------
