@@ -47,6 +47,7 @@
 #include <matroska/KaxVersion.h>
 
 #include "common/chapters/chapters.h"
+#include "common/command_line.h"
 #include "common/container.h"
 #include "common/date_time.h"
 #include "common/debugging.h"
@@ -297,7 +298,10 @@ display_progress(bool is_100percent = false) {
     return;
 
   if (is_100percent) {
-    mxinfo(boost::format(Y("Progress: 100%%%1%")) % "\r");
+    if (g_gui_mode)
+      mxinfo(boost::format("#GUI#progress 100%%\n"));
+    else
+      mxinfo(boost::format(Y("Progress: 100%%%1%")) % "\r");
     return;
   }
 
@@ -319,7 +323,10 @@ display_progress(bool is_100percent = false) {
   // if (2 < current_percentage)
   //   exit(42);
 
-  mxinfo(boost::format(Y("Progress: %1%%%%2%")) % current_percentage % "\r");
+  if (g_gui_mode)
+    mxinfo(boost::format("#GUI#progress %1%%%\n") % current_percentage);
+  else
+    mxinfo(boost::format(Y("Progress: %1%%%%2%")) % current_percentage % "\r");
 
   s_previous_percentage  = current_percentage;
   s_previous_progress_on = current_time;
