@@ -190,14 +190,11 @@ extern int64_t g_max_ns_per_cluster;
 extern int g_max_blocks_per_cluster;
 extern int g_default_tracks[3], g_default_tracks_priority[3];
 
-extern bool g_splitting;
 extern int g_split_max_num_files;
 extern std::string g_splitting_by_chapters_arg;
 
 extern append_mode_e g_append_mode;
 
-extern bool g_stereo_mode_used;
-
 void create_packetizers();
 void calc_attachment_sizes();
 void calc_max_chapter_size();
@@ -217,6 +214,9 @@ void rerender_track_headers();
 void rerender_ebml_head();
 std::string create_output_name();
 
+bool set_required_matroska_version(unsigned int required_version);
+bool set_required_matroska_read_version(unsigned int required_version);
+
 int64_t add_attachment(attachment_t attachment);
 
 #if defined(SYS_UNIX) || defined(SYS_APPLE)
