@@ -2,7 +2,7 @@
    mkvmerge -- utility for splicing together matroska files
    from component media subtypes
 
-   Distributed under the GPL
+   Distributed under the GPL v2
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
@@ -31,7 +31,7 @@ public:
   {
   }
 };
-typedef std::shared_ptr<render_groups_c> render_groups_cptr;
+using render_groups_cptr = std::shared_ptr<render_groups_c>;
 
 struct cluster_helper_c::impl_t {
 public:
