@@ -26,6 +26,13 @@ Job::Job(Status status)
 Job::~Job() {
 }
 
+void
+Job::action(std::function<void()> code) {
+  QMutexLocker locked{&m_mutex};
+
+  code();
+}
+
 void
 Job::setStatus(Status status) {
   QMutexLocker locked{&m_mutex};
@@ -75,6 +82,14 @@ Job::setPendingAuto() {
     setStatus(PendingAuto);
 }
 
+void
+Job::setPendingManual() {
+  QMutexLocker locked{&m_mutex};
+
+  if ((PendingManual != m_status) && (Running != m_status))
+    setStatus(PendingManual);
+}
+
 void
 Job::addLineToInternalLogs(QString const &line,
                            LineType type) {
@@ -83,10 +98,10 @@ Job::addLineToInternalLogs(QString const &line,
                 :                       m_errors;
 
   auto prefix   = InfoLine    == type ? Q("")
-                : WarningLine == type ? QY("Warning: ")
-                :                       QY("Error: ");
+                : WarningLine == type ? Q("%1 ").arg(QY("Warning:"))
+                :                       Q("%1 ").arg(QY("Error:"));
 
-  m_fullOutput << Q("%1%2\n").arg(prefix).arg(line);
+  m_fullOutput << Q("%1%2").arg(prefix).arg(line);
   storage      << line;
 
   if ((WarningLine == type) || (ErrorLine == type))
