@@ -26,8 +26,8 @@ protected:
 
   Model *m_model;
 
-  QAction *m_startAction, *m_viewOutputAction, *m_removeAction, *m_acknowledgeSelectedWarningsAction, *m_acknowledgeSelectedErrorsAction, *m_acknowledgeSelectedWarningsErrorsAction;
-  QMenu *m_jobQueueMenu;
+  QAction *m_startAutomaticallyAction, *m_startManuallyAction, *m_viewOutputAction, *m_removeAction, *m_acknowledgeSelectedWarningsAction, *m_acknowledgeSelectedErrorsAction, *m_acknowledgeSelectedWarningsErrorsAction;
+  QMenu *m_jobQueueMenu, *m_jobsMenu;
 
 public:
   explicit Tool(QWidget *parent, QMenu *jobQueueMenu);
@@ -40,8 +40,11 @@ public:
   virtual void retranslateUi() override;
 
 public slots:
-  void onStart();
+  void onStartAutomatically();
+  void onStartManually();
   void onStartAllPending();
+  void onStopQueueAfterCurrentJob();
+  void onStopQueueImmediately();
   void onViewOutput();
   void onRemove();
   void onRemoveDone();
@@ -62,6 +65,8 @@ public slots:
 protected:
   void setupUiControls();
   void setupToolTips();
+
+  void stopQueue(bool immediately);
 };
 
 }}}
