@@ -22,14 +22,21 @@ PreferencesDialog::PreferencesDialog(QWidget *parent)
 {
   ui->setupUi(this);
 
-  Util::setScrollAreaBackgroundTransparent(ui->mergeScrollArea);
+  ui->tabs->setTabPosition(m_cfg.m_tabPosition);
+  ui->tbOftenUsedXYZ->setTabPosition(m_cfg.m_tabPosition);
+
+  Util::restoreWidgetGeometry(this);
+  Util::fixScrollAreaBackground(ui->mergeScrollArea);
 
   // GUI page
   ui->cbGuiDisableAnimations->setChecked(m_cfg.m_disableAnimations);
+  ui->cbGuiShowToolSelector->setChecked(m_cfg.m_showToolSelector);
   ui->cbGuiWarnBeforeClosingModifiedTabs->setChecked(m_cfg.m_warnBeforeClosingModifiedTabs);
   ui->cbGuiWarnBeforeAbortingJobs->setChecked(m_cfg.m_warnBeforeAbortingJobs);
+  ui->cbGuiShowMoveUpDownButtons->setChecked(m_cfg.m_showMoveUpDownButtons);
   setupOnlineCheck();
   setupInterfaceLanguage();
+  setupTabPositions();
 
   ui->cbGuiUseDefaultJobDescription->setChecked(m_cfg.m_useDefaultJobDescription);
   ui->cbGuiShowOutputOfAllJobs->setChecked(m_cfg.m_showOutputOfAllJobs);
@@ -46,8 +53,8 @@ PreferencesDialog::PreferencesDialog(QWidget *parent)
   ui->cbMAlwaysAddDroppedFiles->setChecked(m_cfg.m_mergeAlwaysAddDroppedFiles);
   ui->cbMAlwaysShowOutputFileControls->setChecked(m_cfg.m_mergeAlwaysShowOutputFileControls);
   ui->cbMClearMergeSettings->setCurrentIndex(static_cast<int>(m_cfg.m_clearMergeSettings));
-  Util::setupLanguageComboBox(*ui->cbMDefaultTrackLanguage, m_cfg.m_defaultTrackLanguage);
-  Util::setupCharacterSetComboBox(*ui->cbMDefaultSubtitleCharset, m_cfg.m_defaultSubtitleCharset);
+  ui->cbMDefaultTrackLanguage->setup().setCurrentByData(m_cfg.m_defaultTrackLanguage);
+  ui->cbMDefaultSubtitleCharset->setup(true, QY("– no selection by default –")).setCurrentByData(m_cfg.m_defaultSubtitleCharset);
   ui->leMDefaultAdditionalCommandLineOptions->setText(m_cfg.m_defaultAdditionalMergeOptions);
 
   setupProcessPriority();
@@ -58,18 +65,15 @@ PreferencesDialog::PreferencesDialog(QWidget *parent)
   // Chapter editor page
   ui->leCENameTemplate->setText(m_cfg.m_chapterNameTemplate);
   ui->cbCEDropLastFromBlurayPlaylist->setChecked(m_cfg.m_dropLastChapterFromBlurayPlaylist);
-  Util::setupLanguageComboBox(*ui->cbCEDefaultLanguage, m_cfg.m_defaultChapterLanguage);
-  Util::setupCountryComboBox(*ui->cbCEDefaultCountry, m_cfg.m_defaultChapterCountry, true, QY("– no selection by default –"));
-
-  // Force scroll bars on combo boxes with a high number of entries.
-  ui->cbMDefaultSubtitleCharset->view()->setVerticalScrollBarPolicy(Qt::ScrollBarAsNeeded);
-  ui->cbCEDefaultCountry       ->view()->setVerticalScrollBarPolicy(Qt::ScrollBarAsNeeded);
+  ui->cbCEDefaultLanguage->setup().setCurrentByData(m_cfg.m_defaultChapterLanguage);
+  ui->cbCEDefaultCountry->setup(true, QY("– no selection by default –")).setCurrentByData(m_cfg.m_defaultChapterCountry);
 
   setupToolTips();
   setupConnections();
 }
 
 PreferencesDialog::~PreferencesDialog() {
+  Util::saveWidgetGeometry(this);
 }
 
 bool
@@ -88,6 +92,7 @@ PreferencesDialog::setupToolTips() {
                    .arg(QY("No information is transmitted to the server.")));
 
   Util::setToolTip(ui->cbGuiDisableAnimations, QY("If checked several short animations used throughout the program as visual clues for the user will be disabled."));
+  Util::setToolTip(ui->cbGuiShowOutputOfAllJobs, QY("If unchecked the tool selector on the left side of the main window will be hidden."));
   Util::setToolTip(ui->cbGuiWarnBeforeClosingModifiedTabs,
                    Q("%1 %2")
                    .arg(QY("If checked the program will ask for confirmation before closing or reloading tabs that have been modified."))
@@ -97,11 +102,16 @@ PreferencesDialog::setupToolTips() {
                    .arg(QY("If checked the program will ask for confirmation before aborting a running job."))
                    .arg(QY("This happens when clicking the »abort« button in a »job output« tab and when quitting the application.")));
 
+  Util::setToolTip(ui->cbGuiShowMoveUpDownButtons,
+                   Q("%1 %2")
+                   .arg(QY("Normally selected entries in list view can be moved around via drag & drop and with keyboard shortcuts (Ctrl+Up, Ctrl+Down)."))
+                   .arg(QY("If checked additional buttons for moving selected entries up and down will be shown next to several list views.")));
+
   Util::setToolTip(ui->cbGuiWarnBeforeOverwriting, QY("If enabled the program will ask for confirmation before overwriting files and jobs."));
   ui->cbGuiWarnBeforeOverwriting->setEnabled(false);
 
   Util::setToolTip(ui->cbGuiUseDefaultJobDescription, QY("If disabled the GUI will let you enter a description for a job when adding it to the queue."));
-  Util::setToolTip(ui->cbGuiShowOutputOfAllJobs,      QY("If enabled the first tab in the »watch jobs« tool will not be cleared when a new job starts."));
+  Util::setToolTip(ui->cbGuiShowOutputOfAllJobs,      QY("If enabled the first tab in the »job output« tool will not be cleared when a new job starts."));
 
   Util::setToolTip(ui->cbGuiRemoveJobs,
                    Q("%1 %2")
@@ -109,9 +119,11 @@ PreferencesDialog::setupToolTips() {
                    .arg(QY("You can opt for having them removed automatically under certain conditions.")));
 
   Util::setToolTip(ui->leCENameTemplate,
-                   Q("%1 %2")
+                   Q("<p>%1 %2</p><p>%3 %4</p>")
                    .arg(QY("This template will be used for new chapter entries."))
-                   .arg(QY("The string '<NUM>' will be replaced by the chapter number.")));
+                   .arg(QY("The string '<NUM>' will be replaced by the chapter number.").toHtmlEscaped())
+                   .arg(QY("You can specify a minimum number of places for the chapter number with '<NUM:places>', e.g. '<NUM:3>'.").toHtmlEscaped())
+                   .arg(QY("The resulting number will be padded with leading zeroes if the number of places is less than specified.")));
   Util::setToolTip(ui->cbCEDefaultLanguage, QY("This is the language that newly added chapter names get assigned automatically."));
   Util::setToolTip(ui->cbCEDefaultCountry, QY("This is the country that newly added chapter names get assigned automatically."));
   Util::setToolTip(ui->cbCEDropLastFromBlurayPlaylist,
@@ -336,14 +348,30 @@ PreferencesDialog::setupEnableMuxingTracksByLanguage() {
   ui->tbMEnableMuxingTracksByLanguage->setItems(QList<Util::SideBySideMultiSelect::Item>::fromVector(QVector<Util::SideBySideMultiSelect::Item>::fromStdVector(allLanguages)), m_cfg.m_enableMuxingTracksByTheseLanguages);
 }
 
+void
+PreferencesDialog::setupTabPositions() {
+  ui->cbGuiTabPositions->clear();
+  ui->cbGuiTabPositions->addItem(QY("top"),    static_cast<int>(QTabWidget::North));
+  ui->cbGuiTabPositions->addItem(QY("bottom"), static_cast<int>(QTabWidget::South));
+  ui->cbGuiTabPositions->addItem(QY("left"),   static_cast<int>(QTabWidget::West));
+  ui->cbGuiTabPositions->addItem(QY("right"),  static_cast<int>(QTabWidget::East));
+
+  Util::setComboBoxIndexIf(ui->cbGuiTabPositions, [this](QString const &, QVariant const &data) {
+    return data.toInt() == static_cast<int>(m_cfg.m_tabPosition);
+  });
+}
+
 void
 PreferencesDialog::save() {
   // GUI page:
   m_cfg.m_uiLocale                           = ui->cbGuiInterfaceLanguage->currentData().toString();
+  m_cfg.m_tabPosition                        = static_cast<QTabWidget::TabPosition>(ui->cbGuiTabPositions->currentData().toInt());
   m_cfg.m_checkForUpdates                    = ui->cbGuiCheckForUpdates->isChecked();
   m_cfg.m_disableAnimations                  = ui->cbGuiDisableAnimations->isChecked();
+  m_cfg.m_showToolSelector                   = ui->cbGuiShowToolSelector->isChecked();
   m_cfg.m_warnBeforeClosingModifiedTabs      = ui->cbGuiWarnBeforeClosingModifiedTabs->isChecked();
   m_cfg.m_warnBeforeAbortingJobs             = ui->cbGuiWarnBeforeAbortingJobs->isChecked();
+  m_cfg.m_showMoveUpDownButtons              = ui->cbGuiShowMoveUpDownButtons->isChecked();
   m_cfg.m_useDefaultJobDescription           = ui->cbGuiUseDefaultJobDescription->isChecked();
   m_cfg.m_showOutputOfAllJobs                = ui->cbGuiShowOutputOfAllJobs->isChecked();
   auto idx                                   = !ui->cbGuiRemoveJobs->isChecked() ? 0 : ui->cbGuiJobRemovalPolicy->currentIndex() + 1;
