@@ -18,8 +18,10 @@ class AddingAppendingFilesDialog : public QDialog {
 public:
   enum class Decision {
     Add,
+    AlwaysAdd,
     Append,
     AddAdditionalParts,
+    AddToNew,
   };
 
 protected:
