@@ -21,6 +21,7 @@ void
 AttachmentModel::reset() {
   beginResetModel();
   removeRows(0, rowCount());
+  m_attachmentMap.clear();
   endResetModel();
 }
 
@@ -31,7 +32,7 @@ AttachmentModel::createRowItems(AttachmentPtr const &attachment)
   for (auto column = 0; column < NumberOfColumns; ++column)
     list << new QStandardItem{};
 
-  list[0]->setData(QVariant::fromValue(attachment), Util::AttachmentRole);
+  list[0]->setData(reinterpret_cast<quint64>(attachment.get()), Util::AttachmentRole);
 
   return list;
 }
@@ -79,7 +80,7 @@ AttachmentModel::removeSelectedAttachments(QItemSelection const &selection) {
   auto sortedRowsToRemove = rowsToRemove.toList();
   std::sort(sortedRowsToRemove.begin(), sortedRowsToRemove.end(), std::greater<int>());
 
-  for (auto row : rowsToRemove)
+  for (auto row : sortedRowsToRemove)
     removeRow(row);
 }
 
@@ -91,6 +92,7 @@ AttachmentModel::addAttachments(QList<AttachmentPtr> const &attachmentsToAdd) {
   for (auto const &attachment : attachmentsToAdd) {
     auto newRow = createRowItems(attachment);
     setRowData(newRow, *attachment);
+    m_attachmentMap[reinterpret_cast<quint64>(attachment.get())] = attachment;
     appendRow(newRow);
   }
 }
@@ -104,7 +106,7 @@ AttachmentModel::replaceAttachments(QList<AttachmentPtr> const &newAttachments)
 AttachmentPtr
 AttachmentModel::attachmentForRow(int row)
   const {
-  return item(row)->data(Util::AttachmentRole).value<AttachmentPtr>();
+  return m_attachmentMap.value(item(row)->data(Util::AttachmentRole).value<quint64>(), AttachmentPtr{});
 }
 
 int
@@ -135,4 +137,52 @@ AttachmentModel::itemsForRow(int row) {
   return list;
 }
 
+Qt::DropActions
+AttachmentModel::supportedDropActions()
+  const {
+  return Qt::MoveAction;
+}
+
+Qt::ItemFlags
+AttachmentModel::flags(QModelIndex const &index)
+  const {
+  auto defaultFlags = QStandardItemModel::flags(index) & ~Qt::ItemIsDropEnabled;
+  return index.isValid() ? defaultFlags | Qt::ItemIsDragEnabled : defaultFlags | Qt::ItemIsDropEnabled;
+}
+
+void
+AttachmentModel::moveAttachmentsUpOrDown(QList<Attachment *> attachments,
+                                         bool up) {
+  auto attachmentRowMap = QHash<Attachment *, int>{};
+  for (auto const &attachment : attachments)
+    attachmentRowMap[attachment] = rowForAttachment(*attachment);
+
+  std::sort(attachments.begin(), attachments.end(), [&attachmentRowMap](Attachment *a, Attachment *b) { return attachmentRowMap[a] < attachmentRowMap[b]; });
+
+  if (!up)
+    std::reverse(attachments.begin(), attachments.end());
+
+  auto couldNotBeMoved = QHash<Attachment *, bool>{};
+  auto isSelected      = QHash<Attachment *, bool>{};
+  auto const direction = up ? -1 : +1;
+  auto const numRows   = rowCount();
+
+  for (auto const &attachment : attachments) {
+    isSelected[attachment] = true;
+
+    auto currentRow = rowForAttachment(*attachment);
+    Q_ASSERT(0 <= currentRow);
+
+    auto targetRow = currentRow + direction;
+
+    if (   (0       >  targetRow)
+        || (numRows <= targetRow)
+        || couldNotBeMoved[attachmentForRow(targetRow).get()])
+      couldNotBeMoved[attachment] = true;
+
+    else
+      insertRow(targetRow, takeRow(currentRow));
+  }
+}
+
 }}}
