@@ -17,6 +17,9 @@ using AttachmentModelPtr = std::shared_ptr<AttachmentModel>;
 class AttachmentModel : public QStandardItemModel {
   Q_OBJECT;
 
+protected:
+  QHash<quint64, AttachmentPtr> m_attachmentMap;
+
 protected:
   static int const NameColumn        = 0;
   static int const MIMETypeColumn    = 1;
@@ -45,6 +48,11 @@ public:
 
   virtual void retranslateUi();
 
+  virtual Qt::DropActions supportedDropActions() const override;
+  virtual Qt::ItemFlags flags(QModelIndex const &index) const override;
+
+  virtual void moveAttachmentsUpOrDown(QList<Attachment *> attachments, bool up);
+
 protected:
   QList<QStandardItem *> createRowItems(AttachmentPtr const &attachment) const;
   void setRowData(QList<QStandardItem *> const &items, Attachment const &attachment);
@@ -53,6 +61,4 @@ protected:
 
 }}}
 
-Q_DECLARE_METATYPE(mtx::gui::Merge::AttachmentPtr);
-
 #endif  // MTX_MKVTOOLNIX_GUI_MERGE_ATTACHMENT_MODEL_H
