@@ -1,6 +1,7 @@
 #include "common/common_pch.h"
 
 #include <QFileDialog>
+#include <QMenu>
 
 #include "common/extern_data.h"
 #include "common/qt.h"
@@ -24,17 +25,22 @@ Tab::setupAttachmentsControls() {
     ui->attachmentMIMEType->addItem(to_qs(mime_type.name), to_qs(mime_type.name));
 
   // Context menu
-  ui->attachments->addAction(m_addAttachmentsAction);
-  ui->attachments->addAction(m_removeAttachmentsAction);
+  m_attachmentsMenu->addAction(m_addAttachmentsAction);
+  m_attachmentsMenu->addAction(m_removeAttachmentsAction);
 
   ui->attachmentMIMEType->view()->setVerticalScrollBarPolicy(Qt::ScrollBarAsNeeded);
   ui->attachmentStyle   ->view()->setVerticalScrollBarPolicy(Qt::ScrollBarAsNeeded);
 
   // Signals & slots
-  connect(ui->attachmentsTab,                &Util::FilesDragDropWidget::filesDropped,                                 this, &Tab::addAttachments);
-  connect(ui->attachments->selectionModel(), SIGNAL(selectionChanged(const QItemSelection &, const QItemSelection &)), this, SLOT(onAttachmentSelectionChanged()));
-  connect(m_addAttachmentsAction,            SIGNAL(triggered()),                                                      this, SLOT(onAddAttachments()));
-  connect(m_removeAttachmentsAction,         SIGNAL(triggered()),                                                      this, SLOT(onRemoveAttachments()));
+  connect(ui->attachmentsTab,                &Util::FilesDragDropWidget::filesDropped,         this, &Tab::addAttachments);
+  connect(ui->attachments->selectionModel(), &QItemSelectionModel::selectionChanged,           this, &Tab::onAttachmentSelectionChanged);
+  connect(m_addAttachmentsAction,            &QAction::triggered,                              this, &Tab::onAddAttachments);
+  connect(m_removeAttachmentsAction,         &QAction::triggered,                              this, &Tab::onRemoveAttachments);
+  connect(ui->moveAttachmentsUp,             &QPushButton::clicked,                            this, &Tab::onMoveAttachmentsUp);
+  connect(ui->moveAttachmentsDown,           &QPushButton::clicked,                            this, &Tab::onMoveAttachmentsDown);
+  connect(ui->attachments,                   &Util::BasicTreeView::ctrlUpPressed,              this, &Tab::onMoveAttachmentsUp);
+  connect(ui->attachments,                   &Util::BasicTreeView::ctrlDownPressed,            this, &Tab::onMoveAttachmentsDown);
+  connect(ui->attachments,                   &Util::BasicTreeView::customContextMenuRequested, this, &Tab::showAttachmentsContextMenu);
 
   onAttachmentSelectionChanged();
 }
@@ -57,6 +63,32 @@ Tab::withSelectedAttachments(std::function<void(Attachment *)> code) {
   }
 }
 
+QList<Attachment *>
+Tab::selectedAttachments()
+  const {
+  auto attachments = QList<Attachment *>{};
+  Util::withSelectedIndexes(ui->attachments, [&attachments, this](QModelIndex const &idx) {
+    auto attachment = m_attachmentsModel->attachmentForRow(idx.row());
+    if (attachment)
+      attachments << attachment.get();
+  });
+
+  return attachments;
+}
+
+void
+Tab::selectAttachments(QList<Attachment *> const &attachments) {
+  auto numColumns = m_attachmentsModel->columnCount() - 1;
+  auto selection  = QItemSelection{};
+
+  for (auto const &attachment : attachments) {
+    auto row = m_attachmentsModel->rowForAttachment(*attachment);
+    selection.select(m_attachmentsModel->index(row, 0), m_attachmentsModel->index(row, numColumns));
+  }
+
+  ui->attachments->selectionModel()->select(selection, QItemSelectionModel::ClearAndSelect);
+}
+
 void
 Tab::onAttachmentNameEdited(QString newValue) {
   withSelectedAttachments([&](Attachment *attachment) { attachment->m_name = newValue; });
@@ -134,6 +166,10 @@ void
 Tab::onAttachmentSelectionChanged() {
   auto selection = ui->attachments->selectionModel()->selection();
   auto numRows   = Util::numSelectedRows(selection);
+
+  ui->moveAttachmentsUp->setEnabled(!!numRows);
+  ui->moveAttachmentsDown->setEnabled(!!numRows);
+
   if (!numRows) {
     enableAttachmentControls(false);
     return;
@@ -163,8 +199,13 @@ Tab::enableAttachmentControls(bool enable) {
                                          ui->attachmentMIMEType, ui->attachmentMIMETypeLabel, ui->attachmentStyle,       ui->attachmentStyleLabel,};
   for (auto &control : controls)
     control->setEnabled(enable);
+}
 
-  m_removeAttachmentsAction->setEnabled(enable);
+void
+Tab::enableAttachmentsActions() {
+  auto hasSelection = !ui->attachments->selectionModel()->selection().isEmpty();
+
+  m_removeAttachmentsAction->setEnabled(hasSelection);
 }
 
 void
@@ -214,4 +255,29 @@ Tab::setupAttachmentsToolTips() {
   Util::setToolTip(ui->attachments, QY("Right-click to add and remove attachments"));
 }
 
+void
+Tab::moveAttachmentsUpOrDown(bool up) {
+  auto attachments = selectedAttachments();
+
+  m_attachmentsModel->moveAttachmentsUpOrDown(attachments, up);
+
+  selectAttachments(attachments);
+}
+
+void
+Tab::onMoveAttachmentsUp() {
+  moveAttachmentsUpOrDown(true);
+}
+
+void
+Tab::onMoveAttachmentsDown() {
+  moveAttachmentsUpOrDown(false);
+}
+
+void
+Tab::showAttachmentsContextMenu(QPoint const &pos) {
+  enableAttachmentsActions();
+  m_attachmentsMenu->exec(ui->attachments->viewport()->mapToGlobal(pos));
+}
+
 }}}
