@@ -6,6 +6,7 @@
 #include <QFileDialog>
 #include <QFileInfo>
 #include <QList>
+#include <QMenu>
 #include <QMessageBox>
 #include <QRegularExpression>
 #include <QString>
@@ -17,8 +18,10 @@
 #include "common/stereo_mode.h"
 #include "mkvtoolnix-gui/app.h"
 #include "mkvtoolnix-gui/forms/merge/tab.h"
+#include "mkvtoolnix-gui/main_window/main_window.h"
 #include "mkvtoolnix-gui/merge/adding_appending_files_dialog.h"
 #include "mkvtoolnix-gui/merge/tab.h"
+#include "mkvtoolnix-gui/merge/tool.h"
 #include "mkvtoolnix-gui/merge/playlist_scanner.h"
 #include "mkvtoolnix-gui/util/file_identifier.h"
 #include "mkvtoolnix-gui/util/file_type_filter.h"
@@ -72,21 +75,36 @@ Tab::setupControlLists() {
                            << ui->cuesLabel            << ui->cues                    << ui->additionalTrackOptionsLabel << ui->additionalTrackOptions;
 }
 
+void
+Tab::setupMoveUpDownButtons() {
+  auto show    = Util::Settings::get().m_showMoveUpDownButtons;
+  auto widgets = QList<QWidget *>{} << ui->moveFilesButtons << ui->moveTracksButtons << ui->moveAttachmentsButtons;
+
+  for (auto const &widget : widgets)
+    widget->setVisible(show);
+}
+
 void
 Tab::setupInputControls() {
+  auto &cfg = Util::Settings::get();
+
   setupControlLists();
+  setupMoveUpDownButtons();
 
   ui->files->setModel(m_filesModel);
   ui->tracks->setModel(m_tracksModel);
   ui->tracks->enterActivatesAllSelected(true);
 
+  cfg.handleSplitterSizes(ui->mergeInputSplitter);
+  cfg.handleSplitterSizes(ui->mergeFilesTracksSplitter);
+
   // Track & chapter language
-  Util::setupLanguageComboBox(*ui->trackLanguage);
-  Util::setupLanguageComboBox(*ui->chapterLanguage, QString{}, true);
+  ui->trackLanguage->setup();
+  ui->chapterLanguage->setup(true);
 
   // Track & chapter character set
-  Util::setupCharacterSetComboBox(*ui->subtitleCharacterSet, QString{}, true);
-  Util::setupCharacterSetComboBox(*ui->chapterCharacterSet,  QString{}, true);
+  ui->subtitleCharacterSet->setup(true);
+  ui->chapterCharacterSet->setup(true);
 
   ui->muxThis->addItem(QString{}, true);
   ui->muxThis->addItem(QString{}, false);
@@ -103,8 +121,12 @@ Tab::setupInputControls() {
   for (auto idx = 0; idx < 3; ++idx)
     ui->defaultTrackFlag->addItem(QString{}, idx);
 
-  for (auto idx = 0; idx < 2; ++idx)
-    ui->forcedTrackFlag->addItem(QString{}, idx);
+  // Originally the »forced track« flag's options where ordered »off,
+  // on«; now they're ordered »yes, no« for consistency with other
+  // flags, requiring the values to be reversed.
+  ui->forcedTrackFlag->addItem(QString{}, 1);
+  ui->forcedTrackFlag->addItem(QString{}, 0);
+  ui->forcedTrackFlag->setCurrentIndex(1);
 
   for (auto idx = 0; idx < 3; ++idx)
     ui->compression->addItem(QString{}, idx);
@@ -119,43 +141,69 @@ Tab::setupInputControls() {
     control->view()->setVerticalScrollBarPolicy(Qt::ScrollBarAsNeeded);
 
   // "files" context menu
-  ui->files->addAction(m_addFilesAction);
-  ui->files->addAction(m_appendFilesAction);
-  ui->files->addAction(m_addAdditionalPartsAction);
-  ui->files->addAction(m_removeFilesAction);
-  ui->files->addAction(m_removeAllFilesAction);
+  m_filesMenu->addAction(m_addFilesAction);
+  m_filesMenu->addAction(m_appendFilesAction);
+  m_filesMenu->addAction(m_addAdditionalPartsAction);
+  m_filesMenu->addSeparator();
+  m_filesMenu->addAction(m_removeFilesAction);
+  m_filesMenu->addAction(m_removeAllFilesAction);
 
   // "tracks" context menu
-  ui->tracks->addAction(m_selectAllTracksAction);
-  ui->tracks->addAction(m_enableAllTracksAction);
-  ui->tracks->addAction(m_disableAllTracksAction);
+  m_tracksMenu->addAction(m_selectAllTracksAction);
+  m_tracksMenu->addMenu(m_selectTracksOfTypeMenu);
+  m_tracksMenu->addAction(m_enableAllTracksAction);
+  m_tracksMenu->addAction(m_disableAllTracksAction);
+
+  m_selectTracksOfTypeMenu->addAction(m_selectAllVideoTracksAction);
+  m_selectTracksOfTypeMenu->addAction(m_selectAllAudioTracksAction);
+  m_selectTracksOfTypeMenu->addAction(m_selectAllSubtitlesTracksAction);
 
   // Connect signals & slots.
-  connect(ui->files,                    &Util::BasicTreeView::filesDropped,         this,          &Tab::addOrAppendDroppedFiles);
-  connect(ui->files,                    &Util::BasicTreeView::deletePressed,        this,          &Tab::onRemoveFiles);
-  connect(ui->files->selectionModel(),  &QItemSelectionModel::selectionChanged,     this,          &Tab::onFileSelectionChanged);
-  connect(ui->files->selectionModel(),  &QItemSelectionModel::selectionChanged,     m_filesModel,  &SourceFileModel::updateSelectionStatus);
-  connect(ui->tracks->selectionModel(), &QItemSelectionModel::selectionChanged,     this,          &Tab::onTrackSelectionChanged);
-  connect(ui->tracks->selectionModel(), &QItemSelectionModel::selectionChanged,     m_tracksModel, &TrackModel::updateSelectionStatus);
-  connect(ui->tracks,                   &Util::BasicTreeView::allSelectedActivated, this,          &Tab::toggleMuxThisForSelectedTracks);
-  connect(ui->tracks,                   &QTreeView::doubleClicked,                  this,          &Tab::toggleMuxThisForSelectedTracks);
+  auto mw = MainWindow::get();
+  connect(ui->files,                        &Util::BasicTreeView::filesDropped,               this,                     &Tab::addOrAppendDroppedFiles);
+  connect(ui->files,                        &Util::BasicTreeView::deletePressed,              this,                     &Tab::onRemoveFiles);
+  connect(ui->files,                        &Util::BasicTreeView::ctrlUpPressed,              this,                     &Tab::onMoveFilesUp);
+  connect(ui->files,                        &Util::BasicTreeView::ctrlDownPressed,            this,                     &Tab::onMoveFilesDown);
+  connect(ui->files,                        &Util::BasicTreeView::customContextMenuRequested, this,                     &Tab::showFilesContextMenu);
+  connect(ui->files->selectionModel(),      &QItemSelectionModel::selectionChanged,           this,                     &Tab::enableMoveFilesButtons);
+  connect(ui->files->selectionModel(),      &QItemSelectionModel::selectionChanged,           m_filesModel,             &SourceFileModel::updateSelectionStatus);
+  connect(ui->tracks->selectionModel(),     &QItemSelectionModel::selectionChanged,           this,                     &Tab::onTrackSelectionChanged);
+  connect(ui->tracks->selectionModel(),     &QItemSelectionModel::selectionChanged,           m_tracksModel,            &TrackModel::updateSelectionStatus);
+  connect(ui->tracks,                       &Util::BasicTreeView::allSelectedActivated,       this,                     &Tab::toggleMuxThisForSelectedTracks);
+  connect(ui->tracks,                       &QTreeView::doubleClicked,                        this,                     &Tab::toggleMuxThisForSelectedTracks);
+  connect(ui->tracks,                       &Util::BasicTreeView::ctrlUpPressed,              this,                     &Tab::onMoveTracksUp);
+  connect(ui->tracks,                       &Util::BasicTreeView::ctrlDownPressed,            this,                     &Tab::onMoveTracksDown);
+  connect(ui->tracks,                       &Util::BasicTreeView::customContextMenuRequested, this,                     &Tab::showTracksContextMenu);
+  connect(ui->moveFilesUp,                  &QPushButton::clicked,                            this,                     &Tab::onMoveFilesUp);
+  connect(ui->moveFilesDown,                &QPushButton::clicked,                            this,                     &Tab::onMoveFilesDown);
+  connect(ui->moveTracksUp,                 &QPushButton::clicked,                            this,                     &Tab::onMoveTracksUp);
+  connect(ui->moveTracksDown,               &QPushButton::clicked,                            this,                     &Tab::onMoveTracksDown);
 
-  connect(m_addFilesAction,             &QAction::triggered,                        this,          &Tab::onAddFiles);
-  connect(m_appendFilesAction,          &QAction::triggered,                        this,          &Tab::onAppendFiles);
-  connect(m_addAdditionalPartsAction,   &QAction::triggered,                        this,          &Tab::onAddAdditionalParts);
-  connect(m_removeFilesAction,          &QAction::triggered,                        this,          &Tab::onRemoveFiles);
-  connect(m_removeAllFilesAction,       &QAction::triggered,                        this,          &Tab::onRemoveAllFiles);
+  connect(m_addFilesAction,                 &QAction::triggered,                              this,                     &Tab::onAddFiles);
+  connect(m_appendFilesAction,              &QAction::triggered,                              this,                     &Tab::onAppendFiles);
+  connect(m_addAdditionalPartsAction,       &QAction::triggered,                              this,                     &Tab::onAddAdditionalParts);
+  connect(m_removeFilesAction,              &QAction::triggered,                              this,                     &Tab::onRemoveFiles);
+  connect(m_removeAllFilesAction,           &QAction::triggered,                              this,                     &Tab::onRemoveAllFiles);
 
-  connect(m_selectAllTracksAction,      &QAction::triggered,                        this,          &Tab::selectAllTracks);
-  connect(m_enableAllTracksAction,      &QAction::triggered,                        this,          &Tab::enableAllTracks);
-  connect(m_disableAllTracksAction,     &QAction::triggered,                        this,          &Tab::disableAllTracks);
+  connect(m_selectAllTracksAction,          &QAction::triggered,                              this,                     &Tab::selectAllTracks);
+  connect(m_selectAllVideoTracksAction,     &QAction::triggered,                              this,                     &Tab::selectAllVideoTracks);
+  connect(m_selectAllAudioTracksAction,     &QAction::triggered,                              this,                     &Tab::selectAllAudioTracks);
+  connect(m_selectAllSubtitlesTracksAction, &QAction::triggered,                              this,                     &Tab::selectAllSubtitlesTracks);
+  connect(m_enableAllTracksAction,          &QAction::triggered,                              this,                     &Tab::enableAllTracks);
+  connect(m_disableAllTracksAction,         &QAction::triggered,                              this,                     &Tab::disableAllTracks);
 
-  connect(m_filesModel,                 &SourceFileModel::rowsInserted,             this,          &Tab::onFileRowsInserted);
-  connect(m_tracksModel,                &TrackModel::rowsInserted,                  this,          &Tab::onTrackRowsInserted);
-  connect(m_tracksModel,                &TrackModel::itemChanged,                   this,          &Tab::onTrackItemChanged);
+  connect(m_filesModel,                     &SourceFileModel::rowsInserted,                   this,                     &Tab::onFileRowsInserted);
+  connect(m_tracksModel,                    &TrackModel::rowsInserted,                        this,                     &Tab::onTrackRowsInserted);
+  connect(m_tracksModel,                    &TrackModel::itemChanged,                         this,                     &Tab::onTrackItemChanged);
 
+  connect(mw,                               &MainWindow::preferencesChanged,                  this,                     &Tab::setupMoveUpDownButtons);
+  connect(mw,                               &MainWindow::preferencesChanged,                  ui->trackLanguage,        &Util::ComboBoxBase::reInitialize);
+  connect(mw,                               &MainWindow::preferencesChanged,                  ui->chapterLanguage,      &Util::ComboBoxBase::reInitialize);
+  connect(mw,                               &MainWindow::preferencesChanged,                  ui->subtitleCharacterSet, &Util::ComboBoxBase::reInitialize);
+  connect(mw,                               &MainWindow::preferencesChanged,                  ui->chapterCharacterSet,  &Util::ComboBoxBase::reInitialize);
+
+  enableMoveFilesButtons();
   onTrackSelectionChanged();
-  enableTracksActions();
 }
 
 void
@@ -276,23 +324,22 @@ Tab::onTrackRowsInserted(QModelIndex const &parentIdx,
                          int) {
   if (parentIdx.isValid())
     ui->tracks->setExpanded(parentIdx, true);
-  enableTracksActions();
-}
-
-void
-Tab::onFileSelectionChanged() {
-  enableFilesActions();
 }
 
 void
 Tab::onTrackSelectionChanged() {
   Util::enableWidgets(m_allInputControls, false);
+  ui->moveTracksUp->setEnabled(false);
+  ui->moveTracksDown->setEnabled(false);
 
   auto selection = ui->tracks->selectionModel()->selection();
   auto numRows   = Util::numSelectedRows(selection);
   if (!numRows)
     return;
 
+  ui->moveTracksUp->setEnabled(true);
+  ui->moveTracksDown->setEnabled(true);
+
   if (1 < numRows) {
     setInputControlValues(nullptr);
     Util::enableWidgets(m_allInputControls, true);
@@ -363,17 +410,17 @@ Tab::setInputControlValues(Track *track) {
     return;
   }
 
-  Util::setComboBoxIndexIf(ui->muxThis,              [&](QString const &, QVariant const &data) { return data.isValid() && (data.toBool()   == track->m_muxThis);           });
-  Util::setComboBoxIndexIf(ui->defaultTrackFlag,     [&](QString const &, QVariant const &data) { return data.isValid() && (data.toUInt()   == track->m_defaultTrackFlag);  });
-  Util::setComboBoxIndexIf(ui->forcedTrackFlag,      [&](QString const &, QVariant const &data) { return data.isValid() && (data.toUInt()   == track->m_forcedTrackFlag);   });
-  Util::setComboBoxIndexIf(ui->compression,          [&](QString const &, QVariant const &data) { return data.isValid() && (data.toUInt()   == track->m_compression);       });
-  Util::setComboBoxIndexIf(ui->cues,                 [&](QString const &, QVariant const &data) { return data.isValid() && (data.toUInt()   == track->m_cues);              });
-  Util::setComboBoxIndexIf(ui->stereoscopy,          [&](QString const &, QVariant const &data) { return data.isValid() && (data.toUInt()   == track->m_stereoscopy);       });
-  Util::setComboBoxIndexIf(ui->naluSizeLength,       [&](QString const &, QVariant const &data) { return data.isValid() && (data.toUInt()   == track->m_naluSizeLength);    });
-  Util::setComboBoxIndexIf(ui->aacIsSBR,             [&](QString const &, QVariant const &data) { return data.isValid() && (data.toUInt()   == track->m_aacIsSBR);          });
+  Util::setComboBoxIndexIf(ui->muxThis,          [&](QString const &, QVariant const &data) { return data.isValid() && (data.toBool() == track->m_muxThis);          });
+  Util::setComboBoxIndexIf(ui->defaultTrackFlag, [&](QString const &, QVariant const &data) { return data.isValid() && (data.toUInt() == track->m_defaultTrackFlag); });
+  Util::setComboBoxIndexIf(ui->forcedTrackFlag,  [&](QString const &, QVariant const &data) { return data.isValid() && (data.toUInt() == track->m_forcedTrackFlag);  });
+  Util::setComboBoxIndexIf(ui->compression,      [&](QString const &, QVariant const &data) { return data.isValid() && (data.toUInt() == track->m_compression);      });
+  Util::setComboBoxIndexIf(ui->cues,             [&](QString const &, QVariant const &data) { return data.isValid() && (data.toUInt() == track->m_cues);             });
+  Util::setComboBoxIndexIf(ui->stereoscopy,      [&](QString const &, QVariant const &data) { return data.isValid() && (data.toUInt() == track->m_stereoscopy);      });
+  Util::setComboBoxIndexIf(ui->naluSizeLength,   [&](QString const &, QVariant const &data) { return data.isValid() && (data.toUInt() == track->m_naluSizeLength);   });
+  Util::setComboBoxIndexIf(ui->aacIsSBR,         [&](QString const &, QVariant const &data) { return data.isValid() && (data.toUInt() == track->m_aacIsSBR);         });
 
-  Util::setComboBoxTextByData(ui->trackLanguage,        track->m_language);
-  Util::setComboBoxTextByData(ui->subtitleCharacterSet, track->m_characterSet);
+  ui->trackLanguage->setCurrentByData(track->m_language);
+  ui->subtitleCharacterSet->setCurrentByData(track->m_characterSet);
 
   ui->trackName->setText(                track->m_name);
   ui->trackTags->setText(                track->m_tags);
@@ -733,7 +780,7 @@ Tab::addOrAppendFiles(bool append,
   }
 
   if (!append)
-    PlaylistScanner{this}.checkAddingPlaylists(identifiedFiles);
+    identifiedFiles = PlaylistScanner{this}.checkAddingPlaylists(identifiedFiles);
 
   if (identifiedFiles.isEmpty())
     return;
@@ -746,6 +793,9 @@ Tab::addOrAppendFiles(bool append,
 
   setDefaultsFromSettingsForAddedFiles(identifiedFiles);
 
+  if (m_config.m_firstInputFileName.isEmpty())
+    m_config.m_firstInputFileName = identifiedFiles[0]->m_fileName;
+
   m_filesModel->addOrAppendFilesAndTracks(sourceFileIdx, identifiedFiles, append);
 
   if (m_debugTrackModel) {
@@ -821,6 +871,7 @@ Tab::onRemoveFiles() {
   reinitFilesTracksControls();
 
   if (!m_filesModel->rowCount()) {
+    m_config.m_firstInputFileName.clear();
     clearDestinationMaybe();
     clearTitleMaybe();
   }
@@ -835,6 +886,7 @@ Tab::onRemoveAllFiles() {
   m_tracksModel->removeRows(0, m_tracksModel->rowCount());
   m_config.m_files.clear();
   m_config.m_tracks.clear();
+  m_config.m_firstInputFileName.clear();
 
   reinitFilesTracksControls();
   clearDestinationMaybe();
@@ -845,10 +897,7 @@ void
 Tab::reinitFilesTracksControls() {
   resizeFilesColumnsToContents();
   resizeTracksColumnsToContents();
-  onFileSelectionChanged();
   onTrackSelectionChanged();
-  enableFilesActions();
-  enableTracksActions();
 }
 
 void
@@ -863,6 +912,14 @@ Tab::resizeTracksColumnsToContents()
   Util::resizeViewColumnsToContents(ui->tracks);
 }
 
+void
+Tab::enableMoveFilesButtons() {
+  auto hasSelected = !ui->files->selectionModel()->selection().isEmpty();
+
+  ui->moveFilesUp->setEnabled(hasSelected);
+  ui->moveFilesDown->setEnabled(hasSelected);
+}
+
 void
 Tab::enableFilesActions() {
   int numSelected      = ui->files->selectionModel()->selection().size();
@@ -882,8 +939,13 @@ Tab::enableTracksActions() {
   bool hasTracks = !!m_tracksModel->rowCount();
 
   m_selectAllTracksAction->setEnabled(hasTracks);
+  m_selectTracksOfTypeMenu->setEnabled(hasTracks);
   m_enableAllTracksAction->setEnabled(hasTracks);
   m_disableAllTracksAction->setEnabled(hasTracks);
+
+  m_selectAllVideoTracksAction->setEnabled(hasTracks);
+  m_selectAllAudioTracksAction->setEnabled(hasTracks);
+  m_selectAllSubtitlesTracksAction->setEnabled(hasTracks);
 }
 
 void
@@ -901,20 +963,25 @@ Tab::retranslateInputUI() {
   m_removeAllFilesAction->setText(QY("Remove a&ll files"));
 
   m_selectAllTracksAction->setText(QY("&Select all tracks"));
+  m_selectTracksOfTypeMenu->setTitle(QY("Select all tracks of specific &type"));
   m_enableAllTracksAction->setText(QY("&Enable all tracks"));
   m_disableAllTracksAction->setText(QY("&Disable all tracks"));
 
+  m_selectAllVideoTracksAction->setText(QY("&Video"));
+  m_selectAllAudioTracksAction->setText(QY("&Audio"));
+  m_selectAllSubtitlesTracksAction->setText(QY("&Subtitles"));
+
   for (auto &comboBox : m_comboBoxControls)
     if (comboBox->count() && !comboBox->itemData(0).isValid())
       comboBox->setItemText(0, QY("<do not change>"));
 
-  Util::setComboBoxTexts(ui->muxThis,          QStringList{} << QY("yes")                     << QY("no"));
+  Util::setComboBoxTexts(ui->muxThis,          QStringList{}                                  << QY("yes")                  << QY("no"));
   Util::setComboBoxTexts(ui->naluSizeLength,   QStringList{} << QY("don't change")            << QY("force 2 bytes")        << QY("force 4 bytes"));
-  Util::setComboBoxTexts(ui->defaultTrackFlag, QStringList{} << QY("determine automatically") << QY("set to \"yes\"")       << QY("set to \"no\""));
-  Util::setComboBoxTexts(ui->forcedTrackFlag,  QStringList{} << QY("off")                     << QY("on"));
+  Util::setComboBoxTexts(ui->defaultTrackFlag, QStringList{} << QY("determine automatically") << QY("yes")                  << QY("no"));
+  Util::setComboBoxTexts(ui->forcedTrackFlag,  QStringList{}                                  << QY("yes")                  << QY("no"));
   Util::setComboBoxTexts(ui->compression,      QStringList{} << QY("determine automatically") << QY("no extra compression") << Q("zlib"));
-  Util::setComboBoxTexts(ui->cues,             QStringList{} << QY("default")                 << QY("only for I frames")    << QY("for all frames") << QY("no cues"));
-  Util::setComboBoxTexts(ui->aacIsSBR,         QStringList{} << QY("default")                 << QY("yes")                  << QY("no"));
+  Util::setComboBoxTexts(ui->cues,             QStringList{} << QY("determine automatically") << QY("only for I frames")    << QY("for all frames") << QY("no cues"));
+  Util::setComboBoxTexts(ui->aacIsSBR,         QStringList{} << QY("determine automatically") << QY("yes")                  << QY("no"));
 
   setupInputToolTips();
 }
@@ -998,10 +1065,10 @@ Tab::setOutputFileNameMaybe(QString const &fileName) {
     outputDir = settings.m_fixedOutputDir;
 
   else if (Util::Settings::ToSameAsFirstInputFile == policy)
-    outputDir = srcFileName.absoluteDir();
+    outputDir = QFileInfo{m_config.m_firstInputFileName}.absoluteDir();
 
   else if (Util::Settings::ToRelativeOfFirstInputFile == policy)
-    outputDir = QDir{ srcFileName.absoluteDir().path() + Q("/") + settings.m_relativeOutputDir.path() };
+    outputDir = QDir{ QFileInfo{m_config.m_firstInputFileName}.absoluteDir().path() + Q("/") + settings.m_relativeOutputDir.path() };
 
   else
     Q_ASSERT_X(false, "setOutputFileNameMaybe", "Untested output file name policy");
@@ -1026,7 +1093,9 @@ Tab::setOutputFileNameMaybe(QString const &fileName) {
 
 void
 Tab::addOrAppendDroppedFiles(QStringList const &fileNames) {
-  if (m_config.m_files.isEmpty() || Util::Settings::get().m_mergeAlwaysAddDroppedFiles) {
+  auto &settings = Util::Settings::get();
+
+  if (m_config.m_files.isEmpty() || settings.m_mergeAlwaysAddDroppedFiles) {
     addOrAppendFiles(false, fileNames, {});
     return;
   }
@@ -1041,8 +1110,17 @@ Tab::addOrAppendDroppedFiles(QStringList const &fileNames) {
   if (AddingAppendingFilesDialog::Decision::AddAdditionalParts == decision)
     m_filesModel->addAdditionalParts(fileIdx, fileNames);
 
-  else
+  else if (AddingAppendingFilesDialog::Decision::AddToNew == decision)
+    MainWindow::mergeTool()->addMultipleFilesToNewSettings(fileNames);
+
+  else {
+    if (AddingAppendingFilesDialog::Decision::AlwaysAdd == decision) {
+      settings.m_mergeAlwaysAddDroppedFiles = true;
+      settings.save();
+    }
+
     addOrAppendFiles(AddingAppendingFilesDialog::Decision::Append == decision, fileNames, fileIdx);
+  }
 }
 
 void
@@ -1058,28 +1136,82 @@ Tab::addFilesToBeAddedOrAppendedDelayed(QStringList const &fileNames) {
 }
 
 void
-Tab::selectAllTracks() {
+Tab::selectAllTracksOfType(boost::optional<Track::Type> type) {
   auto numRows = m_tracksModel->rowCount();
   if (!numRows)
     return;
 
   auto numColumns = m_tracksModel->columnCount() - 1;
-  auto selection  = QItemSelection{m_tracksModel->index(0, 0), m_tracksModel->index(numRows - 1, numColumns - 1)};
+  auto selection  = QItemSelection{};
 
   for (auto row = 0; row < numRows; ++row) {
     auto &track      = *m_config.m_tracks[row];
     auto numAppended = track.m_appendedTracks.count();
 
+    if (!type || (track.m_type == *type))
+      selection.select(m_tracksModel->index(row, 0), m_tracksModel->index(row, numColumns - 1));
+
     if (!numAppended)
       continue;
 
     auto rowIdx = m_tracksModel->index(row, 0);
-    selection.select(m_tracksModel->index(0, 0, rowIdx), m_tracksModel->index(numAppended - 1, numColumns - 1, rowIdx));
+
+    for (auto appendedRow = 0; appendedRow < numAppended; ++appendedRow) {
+      auto &appendedTrack = *track.m_appendedTracks[appendedRow];
+      if (!type || (appendedTrack.m_type == *type))
+        selection.select(m_tracksModel->index(appendedRow, 0, rowIdx), m_tracksModel->index(appendedRow, numColumns - 1, rowIdx));
+    }
   }
 
   ui->tracks->selectionModel()->select(selection, QItemSelectionModel::ClearAndSelect);
 }
 
+void
+Tab::selectAllTracks() {
+  selectAllTracksOfType({});
+}
+
+void
+Tab::selectAllVideoTracks() {
+  selectAllTracksOfType(Track::Video);
+}
+
+void
+Tab::selectAllAudioTracks() {
+  selectAllTracksOfType(Track::Audio);
+}
+
+void
+Tab::selectAllSubtitlesTracks() {
+  selectAllTracksOfType(Track::Subtitles);
+}
+
+void
+Tab::selectTracks(QList<Track *> const &tracks) {
+  auto numColumns = m_tracksModel->columnCount() - 1;
+  auto selection  = QItemSelection{};
+
+  for (auto const &track : tracks) {
+    auto idx = m_tracksModel->indexFromTrack(track);
+    selection.select(idx.sibling(idx.row(), 0), idx.sibling(idx.row(), numColumns));
+  }
+
+  ui->tracks->selectionModel()->select(selection, QItemSelectionModel::ClearAndSelect);
+}
+
+void
+Tab::selectSourceFiles(QList<SourceFile *> const &files) {
+  auto numColumns = m_filesModel->columnCount() - 1;
+  auto selection  = QItemSelection{};
+
+  for (auto const &file : files) {
+    auto idx = m_filesModel->indexFromSourceFile(file);
+    selection.select(idx.sibling(idx.row(), 0), idx.sibling(idx.row(), numColumns));
+  }
+
+  ui->files->selectionModel()->select(selection, QItemSelectionModel::ClearAndSelect);
+}
+
 void
 Tab::enableAllTracks() {
   enableDisableAllTracks(true);
@@ -1120,4 +1252,62 @@ Tab::ensureOneDefaultFlagOnly(Track *thisOneHasIt) {
     }
 }
 
+void
+Tab::moveSourceFilesUpOrDown(bool up) {
+  auto files = selectedSourceFiles();
+
+  m_filesModel->moveSourceFilesUpOrDown(files, up);
+
+  for (auto const &file : files)
+    if (file->isRegular())
+      ui->files->setExpanded(m_filesModel->indexFromSourceFile(file), true);
+
+  selectSourceFiles(files);
+}
+
+void
+Tab::onMoveFilesUp() {
+  moveSourceFilesUpOrDown(true);
+}
+
+void
+Tab::onMoveFilesDown() {
+  moveSourceFilesUpOrDown(false);
+}
+
+void
+Tab::moveTracksUpOrDown(bool up) {
+  auto tracks = selectedTracks();
+
+  m_tracksModel->moveTracksUpOrDown(tracks, up);
+
+  for (auto const &track : tracks)
+    if (track->isRegular() && !track->m_appendedTo)
+      ui->tracks->setExpanded(m_tracksModel->indexFromTrack(track), true);
+
+  selectTracks(tracks);
+}
+
+void
+Tab::onMoveTracksUp() {
+  moveTracksUpOrDown(true);
+}
+
+void
+Tab::onMoveTracksDown() {
+  moveTracksUpOrDown(false);
+}
+
+void
+Tab::showFilesContextMenu(QPoint const &pos) {
+  enableFilesActions();
+  m_filesMenu->exec(ui->files->viewport()->mapToGlobal(pos));
+}
+
+void
+Tab::showTracksContextMenu(QPoint const &pos) {
+  enableTracksActions();
+  m_tracksMenu->exec(ui->tracks->viewport()->mapToGlobal(pos));
+}
+
 }}}
