@@ -206,6 +206,12 @@ MuxConfig::load(QSettings &settings) {
       throw InvalidSettingsX{};
     m_tracks << objectIDToTrack.value(trackID.toLongLong());
   }
+
+  auto value           = settings.value("firstInputFileName");
+  m_firstInputFileName = value.isValid()    ? value.toString()
+                       : !m_files.isEmpty() ? m_files[0]->m_fileName
+                       :                      QString{};
+
   settings.endGroup();
 
   // Load global settings
@@ -253,7 +259,8 @@ MuxConfig::save(QSettings &settings)
   saveSettingsGroup("files",       m_files,       settings);
   saveSettingsGroup("attachments", m_attachments, settings);
 
-  settings.setValue("trackOrder", std::accumulate(m_tracks.begin(), m_tracks.end(), QList<QVariant>{}, [](QList<QVariant> &accu, Track *track) { accu << QVariant{reinterpret_cast<qulonglong>(track)}; return accu; }));
+  settings.setValue("trackOrder",         std::accumulate(m_tracks.begin(), m_tracks.end(), QList<QVariant>{}, [](QList<QVariant> &accu, Track *track) { accu << QVariant{reinterpret_cast<qulonglong>(track)}; return accu; }));
+  settings.setValue("firstInputFileName", m_firstInputFileName);
   settings.endGroup();
 
   settings.beginGroup("global");
@@ -362,9 +369,16 @@ MuxConfig::buildAppendToMapping(QHash<SourceFile *, unsigned int> const &fileNum
   const {
   auto appendToMapping = QStringList{};
   for (auto const &destinationTrack : m_tracks) {
+    auto currentDestinationFileNumber = fileNumbers.value(destinationTrack->m_file);
+    auto currentDestinationTrackId    = destinationTrack->m_id;
+
     for (auto const &sourceTrack : destinationTrack->m_appendedTracks)
-      if (sourceTrack->m_muxThis && (sourceTrack->isAudio() || sourceTrack->isVideo() || sourceTrack->isSubtitles() || sourceTrack->isButtons()))
-        appendToMapping << Q("%1:%2:%3:%4").arg(fileNumbers.value(sourceTrack->m_file)).arg(sourceTrack->m_id).arg(fileNumbers.value(destinationTrack->m_file)).arg(destinationTrack->m_id);
+      if (sourceTrack->m_muxThis && (sourceTrack->isAudio() || sourceTrack->isVideo() || sourceTrack->isSubtitles() || sourceTrack->isButtons())) {
+        appendToMapping << Q("%1:%2:%3:%4").arg(fileNumbers.value(sourceTrack->m_file)).arg(sourceTrack->m_id).arg(currentDestinationFileNumber).arg(currentDestinationTrackId);
+
+        currentDestinationFileNumber = fileNumbers.value(sourceTrack->m_file);
+        currentDestinationTrackId    = sourceTrack->m_id;
+      }
   }
 
   return appendToMapping.isEmpty() ? QStringList{} : QStringList{} << Q("--append-to") << appendToMapping.join(Q(","));
@@ -377,10 +391,6 @@ MuxConfig::buildMkvmergeOptions()
 
   auto &settings = Util::Settings::get();
 
-  // TODO: buildMkvmergeOptions get ui locale from prefs
-  // if (!preferences.m_uiLocale.isEmpty())
-  //   options << Q("--ui-language") << settings.m_uiLocale;
-
   if (Util::Settings::NormalPriority != settings.m_priority)
     options << Q("--priority") << settings.priorityAsString();
 
