@@ -14,6 +14,10 @@ using namespace mtx::gui;
 
 void
 Tab::setupOutputControls() {
+  auto &cfg = Util::Settings::get();
+
+  cfg.handleSplitterSizes(ui->mergeOutputSplitter);
+
   setupOutputFileControls();
 
   m_splitControls << ui->splitOptions << ui->splitOptionsLabel << ui->splitMaxFilesLabel << ui->splitMaxFiles << ui->linkFiles;
@@ -446,8 +450,8 @@ Tab::setOutputControlValues() {
   ui->additionalOptions->setText(m_config.m_additionalOptions);
   ui->webmMode->setChecked(m_config.m_webmMode);
 
-  Util::setComboBoxTextByData(ui->chapterLanguage,     m_config.m_chapterLanguage);
-  Util::setComboBoxTextByData(ui->chapterCharacterSet, m_config.m_chapterCharacterSet);
+  ui->chapterLanguage->setCurrentByData(m_config.m_chapterLanguage);
+  ui->chapterCharacterSet->setCurrentByData(m_config.m_chapterCharacterSet);
 }
 
 }}}
