@@ -5,6 +5,7 @@
 #include "mkvtoolnix-gui/forms/merge/select_playlist_dialog.h"
 #include "mkvtoolnix-gui/merge/select_playlist_dialog.h"
 #include "mkvtoolnix-gui/merge/track.h"
+#include "mkvtoolnix-gui/util/settings.h"
 #include "mkvtoolnix-gui/util/util.h"
 
 #include <QPushButton>
@@ -119,10 +120,16 @@ SelectPlaylistDialog::SelectPlaylistDialog(QWidget *parent,
 }
 
 SelectPlaylistDialog::~SelectPlaylistDialog() {
+  Util::saveWidgetGeometry(this);
 }
 
 void
 SelectPlaylistDialog::setupUi() {
+  auto &cfg = Util::Settings::get();
+
+  cfg.handleSplitterSizes(ui->selectPlaylistDialogSplitter1);
+  cfg.handleSplitterSizes(ui->selectPlaylistDialogSplitter2);
+
   auto items = QList<QTreeWidgetItem *>{};
   for (auto const &scannedFile : m_scannedFiles)
     items << ScannedFileItem::create(*scannedFile);
@@ -136,6 +143,8 @@ SelectPlaylistDialog::setupUi() {
   auto okButton = Util::buttonForRole(ui->buttonBox, QDialogButtonBox::AcceptRole);
   okButton->setText(QY("&Add"));
   okButton->setDefault(true);
+
+  Util::restoreWidgetGeometry(this);
 }
 
 void
