@@ -42,6 +42,8 @@ protected:
   bool m_currentlySettingInputControlValues;
 
   QAction *m_addFilesAction, *m_appendFilesAction, *m_addAdditionalPartsAction, *m_removeFilesAction, *m_removeAllFilesAction, *m_selectAllTracksAction, *m_enableAllTracksAction, *m_disableAllTracksAction;
+  QAction *m_selectAllVideoTracksAction, *m_selectAllAudioTracksAction, *m_selectAllSubtitlesTracksAction;
+  QMenu *m_filesMenu, *m_tracksMenu, *m_attachmentsMenu, *m_selectTracksOfTypeMenu;
 
   // "Attachments" tab:
   AttachmentModel *m_attachmentsModel;
@@ -80,14 +82,25 @@ public slots:
   virtual void onShowCommandLine();
 
   virtual void selectAllTracks();
+  virtual void selectAllVideoTracks();
+  virtual void selectAllAudioTracks();
+  virtual void selectAllSubtitlesTracks();
   virtual void enableAllTracks();
   virtual void disableAllTracks();
 
   virtual void toggleMuxThisForSelectedTracks();
 
-  virtual void onFileSelectionChanged();
   virtual void onTrackSelectionChanged();
 
+  virtual void onMoveFilesUp();
+  virtual void onMoveFilesDown();
+  virtual void onMoveTracksUp();
+  virtual void onMoveTracksDown();
+  virtual void onMoveAttachmentsUp();
+  virtual void onMoveAttachmentsDown();
+  virtual void setupMoveUpDownButtons();
+  virtual void enableMoveFilesButtons();
+
   virtual void onTrackNameEdited(QString newValue);
   virtual void onTrackItemChanged(QStandardItem *item);
   virtual void onMuxThisChanged(int selected);
@@ -127,6 +140,10 @@ public slots:
   virtual void addOrAppendDroppedFilesDelayed();
   virtual void addFilesToBeAddedOrAppendedDelayed(QStringList const &fileNames);
 
+  virtual void showFilesContextMenu(QPoint const &pos);
+  virtual void showTracksContextMenu(QPoint const &pos);
+  virtual void showAttachmentsContextMenu(QPoint const &pos);
+
   // Output tab:
   virtual void setupOutputFileControls();
   virtual void setDestination(QString const &newValue);
@@ -171,6 +188,7 @@ public slots:
 
   virtual void retranslateUi();
   virtual void handleClearingMergeSettings();
+  virtual void setupTabPositions();
 
 protected:
   virtual void setupAttachmentsControls();
@@ -193,6 +211,7 @@ protected:
   virtual void setDefaultsFromSettingsForAddedFiles(QList<SourceFilePtr> const &files);
   virtual void enableFilesActions();
   virtual void enableTracksActions();
+  virtual void enableAttachmentsActions();
   virtual void enableAttachmentControls(bool enable);
   virtual void setInputControlValues(Track *track);
   virtual void setOutputControlValues();
@@ -206,12 +225,23 @@ protected:
   virtual QString getOpenFileName(QString const &title, QString const &filter, QLineEdit *lineEdit);
   virtual QString getSaveFileName(QString const &title, QString const &filter, QLineEdit *lineEdit);
 
+  virtual void moveSourceFilesUpOrDown(bool up);
+  virtual void moveTracksUpOrDown(bool up);
+  virtual void moveAttachmentsUpOrDown(bool up);
+
   virtual void moveOutputFileNameToGlobal();
   virtual void moveOutputFileNameToOutputTab();
 
   virtual QModelIndex selectedSourceFile() const;
   virtual QList<SourceFile *> selectedSourceFiles() const;
+  virtual void selectSourceFiles(QList<SourceFile *> const &files);
+
   virtual QList<Track *> selectedTracks() const;
+  virtual void selectTracks(QList<Track *> const &tracks);
+  virtual void selectAllTracksOfType(boost::optional<Track::Type> type);
+
+  virtual QList<Attachment *> selectedAttachments() const;
+  virtual void selectAttachments(QList<Attachment *> const &attachments);
 
   virtual void addToJobQueue(bool startNow);
 
