@@ -240,7 +240,7 @@ Track::loadSettings(MuxConfig::Loader &l) {
 
 void
 Track::fixAssociations(MuxConfig::Loader &l) {
-  if (isAppended()) {
+  if (isRegular() && isAppended()) {
     auto appendedToID = l.settings.value("appendedTo").toULongLong();
     if ((0 >= appendedToID) || !l.objectIDToTrack.contains(appendedToID))
       throw InvalidSettingsX{};
@@ -324,7 +324,7 @@ Track::buildMkvmergeOptions(MkvmergeOptionBuilder &opt)
       opt.options << Q("--display-dimensions") << Q("%1:%2x%3").arg(sid).arg(m_displayWidth).arg(m_displayHeight);
 
     if (m_stereoscopy)
-      opt.options << Q("--stereo-mode") << Q("%1:%2").arg(sid).arg(m_stereoscopy);
+      opt.options << Q("--stereo-mode") << Q("%1:%2").arg(sid).arg(m_stereoscopy - 1);
 
     if (m_naluSizeLength)
       opt.options << Q("--nalu-size-length") << Q("%1:%2").arg(sid).arg(m_naluSizeLength);
@@ -354,7 +354,7 @@ Track::buildMkvmergeOptions(MkvmergeOptionBuilder &opt)
     opt.options << Q("--timecodes") << Q("%1:%2").arg(sid).arg(m_timecodes);
 
   if (m_fixBitstreamTimingInfo)
-    opt.options << Q("--fix-bitstream-timing-info") << Q("%1:1").arg(sid);
+    opt.options << Q("--fix-bitstream-timing-information") << Q("%1:1").arg(sid);
 
   auto additionalOptions = Q(strip_copy(to_utf8(m_additionalOptions)));
   if (!additionalOptions.isEmpty())
