@@ -6,9 +6,11 @@
 #include <QDateTime>
 #include <QDir>
 #include <QString>
+#include <QTabWidget>
 #include <QVariant>
 
 class QSettings;
+class QSplitter;
 
 namespace mtx { namespace gui { namespace Util {
 
@@ -54,6 +56,7 @@ public:
   QString m_defaultTrackLanguage, m_chapterNameTemplate, m_defaultChapterLanguage, m_defaultChapterCountry, m_defaultSubtitleCharset, m_defaultAdditionalMergeOptions;
   QStringList m_oftenUsedLanguages, m_oftenUsedCountries, m_oftenUsedCharacterSets;
   ProcessPriority m_priority;
+  QTabWidget::TabPosition m_tabPosition;
   QDir m_lastOpenDir, m_lastOutputDir, m_lastConfigDir;
   bool m_setAudioDelayFromFileName, m_autoSetFileTitle, m_disableCompressionForAllTrackTypes, m_mergeAlwaysAddDroppedFiles, m_mergeAlwaysShowOutputFileControls, m_dropLastChapterFromBlurayPlaylist;
   ClearMergeSettingsAction m_clearMergeSettings;
@@ -71,12 +74,14 @@ public:
   bool m_checkForUpdates;
   QDateTime m_lastUpdateCheck;
 
-  bool m_disableAnimations, m_warnBeforeClosingModifiedTabs, m_warnBeforeAbortingJobs;
+  bool m_disableAnimations, m_showToolSelector, m_warnBeforeClosingModifiedTabs, m_warnBeforeAbortingJobs, m_showMoveUpDownButtons;
   QString m_uiLocale;
 
   bool m_enableMuxingTracksByLanguage, m_enableMuxingAllVideoTracks, m_enableMuxingAllAudioTracks, m_enableMuxingAllSubtitleTracks;
   QStringList m_enableMuxingTracksByTheseLanguages;
 
+  QHash<QString, QList<int> > m_splitterSizes;
+
 public:
   Settings();
   void load();
@@ -88,6 +93,12 @@ public:
   void setValue(QString const &group, QString const &key, QVariant const &value);
   QVariant value(QString const &group, QString const &key, QVariant const &defaultValue = QVariant{}) const;
 
+  void handleSplitterSizes(QSplitter *splitter);
+  void restoreSplitterSizes(QSplitter *splitter);
+
+public slots:
+  void storeSplitterSizes();
+
 protected:
   static Settings s_settings;
 
