@@ -101,118 +101,6 @@ setComboBoxTexts(QComboBox *comboBox,
   }
 }
 
-void
-setupLanguageComboBox(QComboBox &comboBox,
-                      QStringList const &initiallySelected,
-                      bool withEmpty,
-                      QString const &emptyTitle) {
-  auto separatorOffset = 0;
-
-  if (withEmpty) {
-    comboBox.addItem(emptyTitle, Q(""));
-    ++separatorOffset;
-  }
-
-  for (auto const &language : App::iso639Languages()) {
-    if (language.second != Q("und"))
-      continue;
-
-    comboBox.addItem(language.first, language.second);
-    comboBox.insertSeparator(1 + separatorOffset);
-    separatorOffset += 2;
-    break;
-  }
-
-  auto &commonLanguages = App::commonIso639Languages();
-  if (!commonLanguages.empty()) {
-    for (auto const &language : commonLanguages)
-      comboBox.addItem(language.first, language.second);
-
-    comboBox.insertSeparator(commonLanguages.size() + separatorOffset);
-  }
-
-  for (auto const &language : App::iso639Languages())
-    comboBox.addItem(language.first, language.second);
-
-  comboBox.view()->setVerticalScrollBarPolicy(Qt::ScrollBarAsNeeded);
-
-  for (auto const &value : initiallySelected)
-    if (setComboBoxTextByData(&comboBox, value))
-      return;
-}
-
-void
-setupLanguageComboBox(QComboBox &comboBox,
-                      QString const &initiallySelected,
-                      bool withEmpty,
-                      QString const &emptyTitle) {
-  setupLanguageComboBox(comboBox, QStringList{} << initiallySelected, withEmpty, emptyTitle);
-}
-
-void
-setupCountryComboBox(QComboBox &comboBox,
-                      QStringList const &initiallySelected,
-                      bool withEmpty,
-                      QString const &emptyTitle) {
-  if (withEmpty)
-    comboBox.addItem(emptyTitle, Q(""));
-
-  auto &commonCountries = App::commonIso3166_1Alpha2Countries();
-  if (!commonCountries.empty()) {
-    for (auto const &country : commonCountries)
-      comboBox.addItem(country.first, country.second);
-
-    comboBox.insertSeparator(commonCountries.size() + (withEmpty ? 1 : 0));
-  }
-
-  for (auto const &country : App::iso3166_1Alpha2Countries())
-    comboBox.addItem(country.first, country.second);
-
-  comboBox.view()->setVerticalScrollBarPolicy(Qt::ScrollBarAsNeeded);
-
-  for (auto const &value : initiallySelected)
-    if (setComboBoxTextByData(&comboBox, value))
-      return;
-}
-
-void
-setupCountryComboBox(QComboBox &comboBox,
-                      QString const &initiallySelected,
-                      bool withEmpty,
-                      QString const &emptyTitle) {
-  setupCountryComboBox(comboBox, QStringList{} << initiallySelected, withEmpty, emptyTitle);
-}
-
-void
-setupCharacterSetComboBox(QComboBox &comboBox,
-                          QStringList const &initiallySelected,
-                          bool withEmpty,
-                          QString const &emptyTitle) {
-  if (withEmpty)
-    comboBox.addItem(emptyTitle, Q(""));
-
-  for (auto const &characterSet : App::characterSets())
-    comboBox.addItem(characterSet, characterSet);
-
-  auto &cfg = Settings::get();
-  if (!cfg.m_oftenUsedCharacterSets.isEmpty())
-    comboBox.insertSeparator(cfg.m_oftenUsedCharacterSets.count() + (withEmpty ? 1 : 0));
-
-  comboBox.view()->setVerticalScrollBarPolicy(Qt::ScrollBarAsNeeded);
-
-  for (auto const &value : initiallySelected)
-    if (setComboBoxTextByData(&comboBox, value))
-      return;
-}
-
-void
-setupCharacterSetComboBox(QComboBox &comboBox,
-                          QString const &initiallySelected,
-                          bool withEmpty,
-                          QString const &emptyTitle) {
-  setupCharacterSetComboBox(comboBox, QStringList{} << initiallySelected, withEmpty, emptyTitle);
-}
-
 void
 enableWidgets(QList<QWidget *> const &widgets,
               bool enable) {
@@ -474,15 +362,8 @@ tabWidgetCloseTabButton(QTabWidget &tabWidget,
 }
 
 void
-setScrollAreaBackgroundTransparent(QScrollArea *scrollArea) {
-  QPalette pal;
-  pal.setColor(QPalette::Window,QColor(0,0,0,0));
-
-  scrollArea->setPalette(pal);
-  scrollArea->setBackgroundRole(QPalette::Window);
-
-  scrollArea->widget()->setPalette(pal);
-  scrollArea->widget()->setBackgroundRole(QPalette::Window);
+fixScrollAreaBackground(QScrollArea *scrollArea) {
+  scrollArea->setBackgroundRole(QPalette::Base);
 }
 
 }}}
