@@ -42,13 +42,6 @@ bool setComboBoxIndexIf(QComboBox *comboBox, std::function<bool(QString const &,
 bool setComboBoxTextByData(QComboBox *comboBox, QString const &data);
 void setComboBoxTexts(QComboBox *comboBox, QStringList const &texts);
 
-void setupLanguageComboBox(QComboBox &comboBox, QStringList const &initiallySelected = {}, bool withEmpty = false, QString const &emptyTitle = {});
-void setupLanguageComboBox(QComboBox &comboBox, QString const &initiallySelected, bool withEmpty = false, QString const &emptyTitle = {});
-void setupCountryComboBox(QComboBox &comboBox, QStringList const &initiallySelected = {}, bool withEmpty = false, QString const &emptyTitle = {});
-void setupCountryComboBox(QComboBox &comboBox, QString const &initiallySelected, bool withEmpty = false, QString const &emptyTitle = {});
-void setupCharacterSetComboBox(QComboBox &comboBox, QStringList const &initiallySelected = {}, bool withEmpty = false, QString const &emptyTitle = {});
-void setupCharacterSetComboBox(QComboBox &comboBox, QString const &initiallySelected, bool withEmpty = false, QString const &emptyTitle = {});
-
 void enableWidgets(QList<QWidget *> const &widgets, bool enable);
 QPushButton *buttonForRole(QDialogButtonBox *box, QDialogButtonBox::ButtonRole role = QDialogButtonBox::AcceptRole);
 
@@ -56,7 +49,7 @@ void saveWidgetGeometry(QWidget *widget);
 void restoreWidgetGeometry(QWidget *widget);
 
 QWidget *tabWidgetCloseTabButton(QTabWidget &tabWidget, int tabIdx);
-void setScrollAreaBackgroundTransparent(QScrollArea *scrollArea);
+void fixScrollAreaBackground(QScrollArea *scrollArea);
 
 // Model stuff
 enum MtxGuiRoles {
