@@ -2,7 +2,7 @@
    mkvmerge GUI -- utility for splicing together matroska files
    from component media subtypes
 
-   Distributed under the GPL
+   Distributed under the GPL v2
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
@@ -141,22 +141,21 @@ cli_options_dlg::init_cli_option_list() {
                                            Z("Allows storing AVC/h.264 video in Video-for-Windows compatibility mode, e.g. when it is read from an AVI")));
   all_cli_options.push_back(cli_option_t(wxU("--engage no_simpleblocks"),
                                            Z("Disable the use of SimpleBlocks instead of BlockGroups.")));
-  all_cli_options.push_back(cli_option_t(wxU("--engage old_aac_codecid"),
-                                           Z("Use the old AAC codec IDs (e.g. 'A_AAC/MPEG4/SBR') instead of the new one ('A_AAC').")));
   all_cli_options.push_back(cli_option_t(wxU("--engage use_codec_state"),
                                            Z("Allows the use of the CodecState element. This is used for e.g. MPEG-1/-2 video tracks for storing the sequence headers.")));
   all_cli_options.push_back(cli_option_t(wxU("--engage remove_bitstream_ar_info"),
                                            Z("Normally mkvmerge keeps aspect ratio information in MPEG4 video bitstreams and puts the information into the container. "
                                              "This option causes mkvmerge to remove the aspect ratio information from the bitstream.")));
-  all_cli_options.push_back(cli_option_t(wxU("--engage merge_truehd_frames"),
-                                           Z("TrueHD audio streams know two frame types: sync frames and non-sync frames. With this switch mkvmerge will put one sync frame "
-                                             "and all following non-sync frames into a single Matroska block. Without it each non-sync frame is put into its own Matroska block.")));
   all_cli_options.push_back(cli_option_t(wxU("--engage vobsub_subpic_stop_cmds"),
                                            Z("Causes mkvmerge to add 'stop display' commands to VobSub subtitle packets that do not contain a duration field.")));
   all_cli_options.push_back(cli_option_t(wxU("--engage no_cue_duration"),
                                            Z("Causes mkvmerge not to write 'CueDuration' elemenets in the cues.")));
   all_cli_options.push_back(cli_option_t(wxU("--engage no_cue_relative_position"),
                                            Z("Causes mkvmerge not to write 'CueRelativePosition' elemenets in the cues.")));
+  all_cli_options.push_back(cli_option_t(wxU("--engage no_delay_for_garbage_in_avi"),
+                                           Z("Garbage at the start of audio tracks in AVI files is normally used for delaying that track. "
+                                             "mkvmerge normally calculates the delay implied by its presence and offsets all of the track's timecodes by it. "
+                                             "This option prevents that behavior.")));
   all_cli_options.push_back(cli_option_t(wxU("--engage cow"),
                                            Z("No help available.")));
 }
