@@ -2,7 +2,7 @@
    mkvmerge GUI -- utility for splicing together matroska files
    from component media subtypes
 
-   Distributed under the GPL
+   Distributed under the GPL v2
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
@@ -48,6 +48,6 @@ public:
   virtual void translate_ui() = 0;
   wxString get_title();
 };
-typedef std::shared_ptr<he_page_base_c> he_page_base_cptr;
+using he_page_base_cptr = std::shared_ptr<he_page_base_c>;
 
 #endif // MTX_HE_PAGE_BASE_H
