@@ -2,7 +2,7 @@
    mkvmerge GUI -- utility for splicing together matroska files
    from component media subtypes
 
-   Distributed under the GPL
+   Distributed under the GPL v2
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
@@ -282,6 +282,7 @@ protected:
   void show_update_notices();
   void show_update_notice(wxString const &version, std::vector<wxString> const &info);
   void show_update_notice_600();
+  void show_deprecation_warning();
 };
 
 extern mmg_dialog *mdlg;
