@@ -2,7 +2,7 @@
    mkvmerge GUI -- utility for splicing together matroska files
    from component media subtypes
 
-   Distributed under the GPL
+   Distributed under the GPL v2
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
@@ -368,7 +368,7 @@ tab_global::translate_ui() {
                                  "In short: global tags apply to the complete file while the tags you can add on the 'input' tab apply to only one track."));
   cb_webm_mode->SetLabel(Z("Create WebM compliant file"));
   cb_webm_mode->SetToolTip(TIP("Create a WebM compliant file. mkvmerge also turns this on if the output file name's extension is \"webm\". This mode "
-                               "enforces several restrictions. The only allowed codecs are VP8 video and Vorbis audio tracks. Neither chapters nor tags are "
+                               "enforces several restrictions. The only allowed codecs are VP8/VP9 video and Vorbis/Opus audio tracks. Neither chapters nor tags are "
                                "allowed. The DocType header item is changed to \"webm\"."));
 
   translate_split_args();
