@@ -2,7 +2,7 @@
    mkvmerge GUI -- utility for splicing together matroska files
    from component media subtypes
 
-   Distributed under the GPL
+   Distributed under the GPL v2
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
@@ -102,6 +102,7 @@ tab_input::tab_input(wxWindow *parent)
 
   b_track_up         = new wxButton(      this, ID_B_TRACKUP,          wxEmptyString);
   b_track_down       = new wxButton(      this, ID_B_TRACKDOWN,        wxEmptyString);
+  b_track_toggle_all = new wxButton(      this, ID_B_TRACK_TOGGLE_ALL, wxEmptyString);
 
   nb_options         = new wxNotebook(    this, ID_NB_OPTIONS,         wxDefaultPosition, wxDefaultSize, wxNB_TOP);
   ti_general         = new tab_input_general(nb_options, this);
@@ -120,10 +121,10 @@ tab_input::tab_input(wxWindow *parent)
   siz_add_remove_buttons->AddGrowableCol(0);
   siz_add_remove_buttons->AddGrowableCol(1);
 
-  siz_add_remove_buttons->Add(b_add_file);
-  siz_add_remove_buttons->Add(b_append_file);
-  siz_add_remove_buttons->Add(b_remove_file);
-  siz_add_remove_buttons->Add(b_remove_all_files);
+  siz_add_remove_buttons->Add(b_add_file,         0, wxGROW);
+  siz_add_remove_buttons->Add(b_append_file,      0, wxGROW);
+  siz_add_remove_buttons->Add(b_remove_file,      0, wxGROW);
+  siz_add_remove_buttons->Add(b_remove_all_files, 0, wxGROW);
 
   auto siz_additional_parts = new wxBoxSizer(wxHORIZONTAL);
   siz_additional_parts->Add(b_additional_parts, 1, wxGROW);
@@ -141,9 +142,10 @@ tab_input::tab_input(wxWindow *parent)
   siz_tracks_label->Add(st_tracks);
 
   auto siz_track_buttons = new wxBoxSizer(wxVERTICAL);
-  siz_track_buttons->Add(b_track_up);
-  siz_track_buttons->Add(b_track_down, 0, wxTOP, TOPBOTTOMSPACING);
+  siz_track_buttons->Add(b_track_up, 0, wxGROW);
+  siz_track_buttons->Add(b_track_down, 0, wxTOP | wxGROW, TOPBOTTOMSPACING);
   siz_track_buttons->AddStretchSpacer();
+  siz_track_buttons->Add(b_track_toggle_all, 0, wxGROW);
 
   auto siz_tracks = new wxBoxSizer(wxHORIZONTAL);
   siz_tracks->Add(clb_tracks,        1, wxGROW | wxALIGN_TOP);
@@ -174,6 +176,7 @@ tab_input::tab_input(wxWindow *parent)
   clb_tracks  ->Enable(false);
   b_track_up  ->Enable(false);
   b_track_down->Enable(false);
+  b_track_toggle_all->Enable(false);
 
   set_track_mode(nullptr);
   enable_file_controls();
@@ -197,6 +200,7 @@ tab_input::translate_ui() {
   st_tracks->SetLabel(Z("Tracks, chapters and tags:"));
   b_track_up->SetLabel(Z("up"));
   b_track_down->SetLabel(Z("down"));
+  b_track_toggle_all->SetLabel(Z("toggle all"));
   b_additional_parts->SetLabel(Z("additional parts"));
   nb_options->SetPageText(0, Z("General track options"));
   nb_options->SetPageText(1, Z("Format specific options"));
@@ -774,6 +778,7 @@ tab_input::add_file(wxString const &file_name,
 
   st_tracks->Enable(true);
   clb_tracks->Enable(true);
+  b_track_toggle_all->Enable(true);
   enable_file_controls();
 }
 
@@ -846,6 +851,7 @@ tab_input::on_remove_file(wxCommandEvent &) {
   enable_file_controls();
   b_track_up->Enable(-1 != selected_file);
   b_track_down->Enable(-1 != selected_file);
+  b_track_toggle_all->Enable(!tracks.empty());
 
   selected_track = clb_tracks->GetSelection();
   set_track_mode(-1 == selected_track ? nullptr : tracks[selected_track]);
@@ -876,6 +882,7 @@ tab_input::on_remove_all_files(wxCommandEvent &) {
   clb_tracks->Enable(false);
   b_track_up->Enable(false);
   b_track_down->Enable(false);
+  b_track_toggle_all->Enable(false);
 
   set_track_mode(nullptr);
   enable_file_controls();
@@ -897,6 +904,24 @@ tab_input::on_additional_parts(wxCommandEvent &) {
     file->other_files = dlg.get_file_names();
 }
 
+void
+tab_input::on_toggle_all_tracks(wxCommandEvent &) {
+  auto new_enabled = false;
+
+  for (auto const &track : tracks)
+    if (!track->enabled) {
+      new_enabled = true;
+      break;
+    }
+
+  auto idx = 0u;
+  for (auto const &track : tracks) {
+    track->enabled = new_enabled;
+    clb_tracks->Check(idx, new_enabled);
+    ++idx;
+  }
+}
+
 void
 tab_input::on_move_track_up(wxCommandEvent &) {
   if (1 > selected_track)
@@ -997,6 +1022,7 @@ tab_input::on_track_selected(wxCommandEvent &) {
   ti_extra->tc_user_defined->SetValue(t->user_defined);
 
   ti_format->cb_aac_is_sbr->SetValue(t->aac_is_sbr);
+  ti_format->cb_reduce_to_core->SetValue(t->reduce_to_core);
   ti_format->cb_fix_bitstream_timing_info->SetValue(t->fix_bitstream_timing_info);
   ti_format->cob_nalu_size_length->SetSelection(t->nalu_size_length / 2);
   ti_format->cob_stereo_mode->SetSelection(t->stereo_mode);
@@ -1102,6 +1128,7 @@ tab_input::save(wxConfigBase *cfg) {
       cfg->Write(wxT("default_track_2"),             t->default_track);
       cfg->Write(wxT("forced_track"),                t->forced_track);
       cfg->Write(wxT("aac_is_sbr"),                  t->aac_is_sbr);
+      cfg->Write(wxT("reduce_to_core"),              t->reduce_to_core);
       cfg->Write(wxT("fix_bitstream_timing_info"),   t->fix_bitstream_timing_info);
       cfg->Write(wxT("language"),                    t->language);
       cfg->Write(wxT("track_name"),                  t->track_name);
@@ -1159,6 +1186,7 @@ tab_input::load(wxConfigBase *cfg,
 
   clb_tracks->Clear();
   lb_input_files->Clear();
+  b_track_toggle_all->Enable(false);
   set_track_mode(nullptr);
   selected_file  = -1;
   selected_track = -1;
@@ -1233,6 +1261,7 @@ tab_input::load(wxConfigBase *cfg,
         cfg->Read(wxT("default_track_2"),           &tr->default_track,               0);
       cfg->Read(wxT("forced_track"),                &tr->forced_track,                false);
       cfg->Read(wxT("aac_is_sbr"),                  &tr->aac_is_sbr,                  false);
+      cfg->Read(wxT("reduce_to_core"),              &tr->reduce_to_core,              false);
       cfg->Read(wxT("fix_bitstream_timing_info"),   &tr->fix_bitstream_timing_info,   false);
       cfg->Read(wxT("language"),                    &tr->language);
       cfg->Read(wxT("track_name"),                  &tr->track_name);
@@ -1344,6 +1373,7 @@ tab_input::load(wxConfigBase *cfg,
   }
   st_tracks->Enable(!tracks.empty());
   clb_tracks->Enable(!tracks.empty());
+  b_track_toggle_all->Enable(!tracks.empty());
 
   dont_copy_values_now = false;
 
@@ -1522,7 +1552,7 @@ tab_input::check_for_and_handle_playlist_file(wxString const &file_name,
     cont = dir.GetNext(&other_file_name);
   }
 
-  if (2 > other_files.size())
+  if (other_files.empty())
     return file_name;
 
   if (SDP_ALWAYS_ASK == mdlg->options.scan_directory_for_playlists) {
@@ -1592,6 +1622,7 @@ BEGIN_EVENT_TABLE(tab_input, wxPanel)
   EVT_BUTTON(ID_B_ADDITIONAL_PARTS, tab_input::on_additional_parts)
   EVT_BUTTON(ID_B_TRACKUP,          tab_input::on_move_track_up)
   EVT_BUTTON(ID_B_TRACKDOWN,        tab_input::on_move_track_down)
+  EVT_BUTTON(ID_B_TRACK_TOGGLE_ALL, tab_input::on_toggle_all_tracks)
 
   EVT_LISTBOX(ID_LB_INPUTFILES,     tab_input::on_file_selected)
   EVT_LISTBOX(ID_CLB_TRACKS,        tab_input::on_track_selected)
