@@ -27,7 +27,7 @@ protected:
   ac3::parser_c m_parser;
   timecode_calculator_c m_timecode_calculator;
   int64_t m_samples_per_packet, m_packet_duration;
-  bool m_framed, m_first_packet, m_flush_after_each_packet;
+  bool m_framed, m_first_packet;
 
 public:
   ac3_packetizer_c(generic_reader_c *p_reader, track_info_c &p_ti, int samples_per_sec, int channels, int bsid, bool framed = false);
@@ -36,7 +36,6 @@ public:
   virtual int process(packet_cptr packet);
   virtual void flush_packets();
   virtual void set_headers();
-  virtual void enable_flushing_after_each_packet(bool flush_after_each_packet);
 
   virtual translatable_string_c get_format_name() const {
     return YT("AC3");
