@@ -2,7 +2,7 @@
    mkvmerge -- utility for splicing together matroska files
    from component media subtypes
 
-   Distributed under the GPL
+   Distributed under the GPL v2
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
@@ -19,17 +19,18 @@
 #include "common/byte_buffer.h"
 #include "common/mp3.h"
 #include "common/samples_timecode_conv.h"
-#include "merge/pr_generic.h"
+#include "merge/generic_packetizer.h"
+#include "merge/timecode_calculator.h"
 
 class mp3_packetizer_c: public generic_packetizer_c {
 private:
-  int64_t m_packetno, m_bytes_skipped;
+  bool m_first_packet;
+  int64_t m_bytes_skipped;
   int m_samples_per_sec, m_channels, m_samples_per_frame;
   byte_buffer_c m_byte_buffer;
   bool m_codec_id_set, m_valid_headers_found;
-  int64_t m_previous_timecode, m_num_packets_since_previous_timecode;
-  samples_to_timecode_converter_c m_s2tc;
-  int64_t m_single_packet_duration;
+  timecode_calculator_c m_timecode_calculator;
+  int64_t m_packet_duration;
 
 public:
   mp3_packetizer_c(generic_reader_c *p_reader, track_info_c &p_ti, int samples_per_sec, int channels, bool source_is_good);
