@@ -2,7 +2,7 @@
    mkvmerge -- utility for splicing together matroska files
    from component media subtypes
 
-   Distributed under the GPL
+   Distributed under the GPL v2
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
@@ -18,7 +18,7 @@
 #include "common/common_pch.h"
 
 #include "common/compression.h"
-#include "merge/pr_generic.h"
+#include "merge/generic_packetizer.h"
 
 class vobbtn_packetizer_c: public generic_packetizer_c {
 protected:
