@@ -9,7 +9,7 @@ class SimpleTest
     file_name = class_name_to_file_name class_name
     content   = IO.readlines(file_name).join("")
 
-    if ! /class\s+.*?\s+<\s+Test/.match(content)
+    if ! %r{class\s+.*?\s+<\s+Test}.match(content)
       content = %Q!
         class ::#{class_name} < SimpleTest
           def initialize
@@ -90,7 +90,7 @@ class SimpleTest
 
   def unlink_tmp_files
     return if ENV["KEEP_TMPFILES"] == "1"
-    re = /^#{self.tmp_name_prefix}/
+    re = %r{^#{self.tmp_name_prefix}}
     Dir.entries("/tmp").each do |entry|
       file = "/tmp/#{entry}"
       File.unlink(file) if re.match(file) and File.exists?(file)
@@ -110,7 +110,7 @@ class SimpleTest
       :block => lambda {
         output = options[:output] || tmp
         merge full_command_line, :exit_code => options[:exit_code], :output => output
-        options[:keep_tmp] ? hash_file(output) : hash_tmp
+        options[:exit_code] == :error ? 'error' : options[:keep_tmp] ? hash_file(output) : hash_tmp
       },
     }
   end
@@ -133,6 +133,20 @@ class SimpleTest
     }
   end
 
+  def test_info file, *args
+    options             = args.extract_options!
+    full_command_line   = [ options[:args], file ].flatten.join(' ')
+    options[:name]    ||= full_command_line
+    @blocks[:tests] << {
+      :name  => full_command_line,
+      :block => lambda {
+        output = options[:output] || tmp
+        info full_command_line, :exit_code => options[:exit_code], :output => output
+        options[:keep_tmp] ? hash_file(output) : hash_tmp
+      },
+    }
+  end
+
   def test_merge_unsupported file, *args
     options             = args.extract_options!
     full_command_line   = [ options[:args], file ].flatten.join(' ')
@@ -141,7 +155,7 @@ class SimpleTest
       :name  => full_command_line,
       :block => lambda {
         sys "../src/mkvmerge --identify-verbose #{full_command_line} > #{tmp}", :exit_code => 3
-        /unsupported container/.match(IO.readlines(tmp).first || '') ? :ok : :bad
+        %r{unsupported container}.match(IO.readlines(tmp).first || '') ? :ok : :bad
       },
     }
   end
@@ -218,7 +232,7 @@ class SimpleTest
     fail ArgumentError if args.empty?
 
     output  = options[:output] || self.tmp
-    output  = "> #{output}" unless /^[>\|]/.match(output)
+    output  = "> #{output}" unless %r{^[>\|]}.match(output)
     output  = '' if options[:output] == :return
     command = "../src/mkvinfo --engage no_variable_data --ui-language en_US #{args.first} #{output}"
     self.sys command, :exit_code => options[:exit_code]
@@ -234,12 +248,16 @@ class SimpleTest
     self.sys command, :exit_code => options[:exit_code]
   end
 
-  def propedit *args
+  def propedit file_name, *args
     options = args.extract_options!
     fail ArgumentError if args.empty?
 
-    command  = "../src/mkvpropedit --engage no_variable_data #{args.first}"
-    self.sys command, :exit_code => options[:exit_code]
+    command = "../src/mkvpropedit --engage no_variable_data #{file_name} #{args.first}"
+    *result = self.sys command, :exit_code => options[:exit_code]
+
+    self.sys "../src/tools/ebml_validator -M #{file_name}" if FileTest.exists?("../src/tools/ebml_validator")
+
+    return *result
   end
 
   def sys *args
@@ -250,7 +268,7 @@ class SimpleTest
     command    = args.shift
     @commands << command
 
-    if !/>/.match command
+    if !%r{>}.match command
       temp_file = Tempfile.new('mkvtoolnix-test-output')
       temp_file.close
       command  << " >#{temp_file.path} 2>&1 "
